% Auto-generated chapter 68 for bukhari
% Hadiths in this chapter: 95

\hadithdefcmd{bukhari}{5251}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ بْنُ الْخَطَّابِ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا، ثُمَّ لِيُمْسِكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ، ثُمَّ تَطْهُرَ، ثُمَّ إِنْ شَاءَ أَمْسَكَ بَعْدُ وَإِنْ شَاءَ طَلَّقَ قَبْلَ أَنْ يَمَسَّ، فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ ‏"‏‏.‏\hadithno{5251}\hadithtrans{Narrated `Abdullah bin `Umar:that he had divorced his wife while she was menstruating during the lifetime of Allah's Messenger (ﷺ) . `Umar bin Al-Khattab asked Allah's Messenger (ﷺ) about that. Allah's Messenger (ﷺ) said, "Order him (your son) to take her back and keep her till she is clean and then to wait till she gets her next period and becomes clean again, whereupon, if he wishes to keep her, he can do so, and if he wishes to divorce her he can divorce her before having sexual intercourse with her; and that is the prescribed period which Allah has fixed for the women meant to be divorced}}
\hadithdefcmd{bukhari}{5252}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، قَالَ طَلَّقَ ابْنُ عُمَرَ امْرَأَتَهُ وَهْىَ حَائِضٌ، فَذَكَرَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ لِيُرَاجِعْهَا ‏"‏‏.‏ قُلْتُ تُحْتَسَبُ قَالَ ‏"‏ فَمَهْ ‏"‏‏.‏ وَعَنْ قَتَادَةَ عَنْ يُونُسَ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ قَالَ ‏"‏ مُرْهُ فَلْيُرَاجِعْهَا ‏"‏‏.‏ قُلْتُ تُحْتَسَبُ قَالَ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ‏.‏\hadithno{5252}\hadithtrans{Narrated Anas bin Seereen:Ibn `Umar said: "I divorced my wife while she was menstruating. `Umar mentioned that to the Prophet . The Prophet (ﷺ) said, (to my father), "Let your son take her back." I asked (Ibn `Umar), "Is such a divorce counted (i.e. as one legal divorce)?" Ibn `Umar said, "Of course." Narrated Yunus bin Jubair: Ibn `Umar said, "The Prophet (ﷺ) said to `Umar, 'Order him (Ibn `Umar) to take her back.' " I asked, "Is such a divorce counted (as one legal divorce)?" Ibn `Umar said, "What do you think if someone becomes helpless and foolish?}}
\hadithdefcmd{bukhari}{5253}{وَقَالَ أَبُو مَعْمَرٍ حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ حُسِبَتْ عَلَىَّ بِتَطْلِيقَةٍ‏.‏\hadithno{5253}\hadithtrans{Narrated Ibn `Umar:(Divorcing my wife during her menses) was counted as one legal divorce}}
\hadithdefcmd{bukhari}{5254}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ سَأَلْتُ الزُّهْرِيَّ أَىُّ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اسْتَعَاذَتْ مِنْهُ قَالَ أَخْبَرَنِي عُرْوَةُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ ابْنَةَ الْجَوْنِ لَمَّا أُدْخِلَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَدَنَا مِنْهَا قَالَتْ أَعُوذُ بِاللَّهِ مِنْكَ‏.‏ فَقَالَ لَهَا ‏ "‏ لَقَدْ عُذْتِ بِعَظِيمٍ، الْحَقِي بِأَهْلِكِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ رَوَاهُ حَجَّاجُ بْنُ أَبِي مَنِيعٍ عَنْ جَدِّهِ عَنِ الزُّهْرِيِّ أَنَّ عُرْوَةَ أَخْبَرَهُ أَنَّ عَائِشَةَ قَالَتْ‏.‏\hadithno{5254}\hadithtrans{Narrated Al-Awza:I asked Az-Zuhri, "Which of the wives of the Prophet (ﷺ) sought refuge with Allah from him?" He said "I was told by 'Urwa that `Aisha said, 'When the daughter of Al-Jaun was brought to Allah's Messenger (ﷺ) (as his bride) and he went near her, she said, "I seek refuge with Allah from you." He said, "You have sought refuge with The Great; return to your family}}
\hadithdefcmd{bukhari}{5255}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ غَسِيلٍ، عَنْ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ، عَنْ أَبِي أُسَيْدٍ ـ رضى الله عنه ـ قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم حَتَّى انْطَلَقْنَا إِلَى حَائِطٍ يُقَالُ لَهُ الشَّوْطُ، حَتَّى انْتَهَيْنَا إِلَى حَائِطَيْنِ فَجَلَسْنَا بَيْنَهُمَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اجْلِسُوا هَا هُنَا ‏"‏‏.‏ وَدَخَلَ وَقَدْ أُتِيَ بِالْجَوْنِيَّةِ، فَأُنْزِلَتْ فِي بَيْتٍ فِي نَخْلٍ فِي بَيْتٍ أُمَيْمَةُ بِنْتُ النُّعْمَانِ بْنِ شَرَاحِيلَ وَمَعَهَا دَايَتُهَا حَاضِنَةٌ لَهَا، فَلَمَّا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ هَبِي نَفْسَكِ لِي ‏"‏‏.‏ قَالَتْ وَهَلْ تَهَبُ الْمَلِكَةُ نَفْسَهَا لِلسُّوقَةِ‏.‏ قَالَ فَأَهْوَى بِيَدِهِ يَضَعُ يَدَهُ عَلَيْهَا لِتَسْكُنَ فَقَالَتْ أَعُوذُ بِاللَّهِ مِنْكَ‏.‏ فَقَالَ ‏"‏ قَدْ عُذْتِ بِمَعَاذٍ ‏"‏‏.‏ ثُمَّ خَرَجَ عَلَيْنَا، فَقَالَ ‏"‏ يَا أَبَا أُسَيْدٍ اكْسُهَا رَازِقِيَّتَيْنِ وَأَلْحِقْهَا بِأَهْلِهَا‏"‏‏.‏\hadithno{5255}\hadithtrans{Narrated Abu Usaid:We went out with the Prophet (ﷺ) to a garden called Ash-Shaut till we reached two walls between which we sat down. The Prophet (ﷺ) said, "Sit here," and went in (the garden). The Jauniyya (a lady from Bani Jaun) had been brought and lodged in a house in a date-palm garden in the home of Umaima bint An- Nu`man bin Sharahil, and her wet nurse was with her. When the Prophet (ﷺ) entered upon her, he said to her, "Give me yourself (in marriage) as a gift." She said, "Can a princess give herself in marriage to an ordinary man?" The Prophet (ﷺ) raised his hand to pat her so that she might become tranquil. She said, "I seek refuge with Allah from you." He said, "You have sought refuge with One Who gives refuge. Then the Prophet (ﷺ) came out to us and said, "O Abu Usaid! Give her two white linen dresses to wear and let her go back to her family}}
\hadithdefcmd{bukhari}{5256}{وَقَالَ الْحُسَيْنُ بْنُ الْوَلِيدِ النَّيْسَابُورِيُّ عَنْ عَبْدِ الرَّحْمَنِ، عَنْ عَبَّاسِ بْنِ سَهْلٍ، عَنْ أَبِيهِ، وَأَبِي، أُسَيْدٍ قَالاَ تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم أُمَيْمَةَ بِنْتَ شَرَاحِيلَ، فَلَمَّا أُدْخِلَتْ عَلَيْهِ بَسَطَ يَدَهُ إِلَيْهَا فَكَأَنَّهَا كَرِهَتْ ذَلِكَ فَأَمَرَ أَبَا أُسَيْدٍ أَنْ يُجَهِّزَهَا وَيَكْسُوَهَا ثَوْبَيْنِ رَازِقِيَّيْنِ‏.‏\hadithno{5256}\hadithtrans{Narrated Sahl and Abu Usaid:The Prophet (ﷺ) married Umaima bint Sharahil, and when she was brought to him, he stretched his hand towards her. It seemed that she disliked that, whereupon the Prophet (ﷺ) ordered Abu Usaid to prepare her and to provide her with two white linen dresses}}
\hadithdefcmd{bukhari}{5257}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ حَمْزَةَ، عَنْ أَبِيهِ، وَعَنْ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، بِهَذَا‏.‏\hadithno{5257}\hadithtrans{Narrated Sahl bin Sa`d:similarly as above}}
\hadithdefcmd{bukhari}{5258}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَبِي غَلاَّبٍ، يُونُسَ بْنِ جُبَيْرٍ قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ‏.‏ فَقَالَ تَعْرِفُ ابْنَ عُمَرَ إِنَّ ابْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَأَمَرَهُ أَنْ يُرَاجِعَهَا فَإِذَا طَهُرَتْ فَأَرَادَ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا، قُلْتُ فَهَلْ عَدَّ ذَلِكَ طَلاَقًا قَالَ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ‏.‏\hadithno{5258}\hadithtrans{Narrated Abi Ghallab Yunus bin Jubair:I asked Ibn `Umar,"(What is said regarding) a man divorces his wife during her period?" He said, "Do you know Ibn `Umar? Ibn `Umar divorced his wife while she was menstruating. `Umar then went to the Prophet (ﷺ) and mentioned that to him. The Prophet (ﷺ) ordered him to take her back and when she became clean, he could divorce her if he wanted." I asked (Ibn `Umar), "Was that divorce counted as one legal divorce?" He said, "If one becomes helpless and foolish (will he be excused? Of course not)}}
\hadithdefcmd{bukhari}{5259}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ عُوَيْمِرًا الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ الأَنْصَارِيِّ، فَقَالَ لَهُ يَا عَاصِمُ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ، أَمْ كَيْفَ يَفْعَلُ سَلْ لِي يَا عَاصِمُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عَاصِمٌ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَ عُوَيْمِرٌ فَقَالَ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمٌ لَمْ تَأْتِنِي بِخَيْرٍ، قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتُهُ عَنْهَا‏.‏ قَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَهُ عَنْهَا فَأَقْبَلَ عُوَيْمِرٌ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ، أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أَنْزَلَ اللَّهُ فِيكَ وَفِي صَاحِبَتِكَ فَاذْهَبْ فَأْتِ بِهَا ‏"‏‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَا قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ، إِنْ أَمْسَكْتُهَا، فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانَتْ تِلْكَ سُنَّةُ الْمُتَلاَعِنَيْنِ‏.‏\hadithno{5259}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:Uwaimir Al-`Ajlani came to `Asim bin Adi Al-Ansari and asked, "O `Asim! Tell me, if a man sees his wife with another man, should he kill him, whereupon you would kill him in Qisas, or what should he do? O `Asim! Please ask Allah's Messenger (ﷺ) about that." `Asim asked Allah's Messenger (ﷺ) about that. Allah's Apostle disliked that question and considered it disgraceful. What `Asim heard from Allah's Messenger (ﷺ) was hard on him. When he returned to his family, 'Uwaimir came to him and said "O `Asim! What did Allah's Messenger (ﷺ) say to you?" `Asim said, "You never bring me any good. Allah's Messenger (ﷺ) disliked to hear the problem which I asked him about." 'Uwaimir said, "By Allah, I will not leave the matter till I ask him about it." So 'Uwaimir proceeded till he came to Allah's Messenger (ﷺ) who was in the midst of the people and said, "O Allah's Messenger (ﷺ)! If a man finds with his wife another man, should he kill him, whereupon you would kill him (in Qisas): or otherwise, what should he do?" Allah's Messenger (ﷺ) said, "Allah has revealed something concerning the question of you and your wife. Go and bring her here." So they both carried out the judgment of Lian, while I was present among the people (as a witness). When both of them had finished, 'Uwaimir said, "O Allah's Messenger (ﷺ)! If I should now keep my wife with me, then I have told a lie". Then he pronounced his decision to divorce her thrice before Allah's Apostle ordered him to do so. (Ibn Shihab said, "That was the tradition for all those who are involved in a case of Lian)}}
\hadithdefcmd{bukhari}{5260}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ امْرَأَةَ رِفَاعَةَ الْقُرَظِيِّ جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ رِفَاعَةَ طَلَّقَنِي فَبَتَّ طَلاَقِي، وَإِنِّي نَكَحْتُ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ الْقُرَظِيَّ، وَإِنَّمَا مَعَهُ مِثْلُ الْهُدْبَةِ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ، لاَ، حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏‏.‏\hadithno{5260}\hadithtrans{Narrated `Aisha:The wife of Rifa`a Al-Qurazi came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Rifa`a divorced me irrevocably. After him I married `Abdur-Rahman bin Az-Zubair Al-Qurazi who proved to be impotent." Allah's Messenger (ﷺ) said to her, "Perhaps you want to return to Rifa`a? Nay (you cannot return to Rifa`a) until you and `Abdur-Rahman consummate your marriage}}
\hadithdefcmd{bukhari}{5261}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي الْقَاسِمُ بْنُ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، طَلَّقَ امْرَأَتَهُ ثَلاَثًا، فَتَزَوَّجَتْ فَطَلَّقَ فَسُئِلَ النَّبِيُّ صلى الله عليه وسلم أَتَحِلُّ لِلأَوَّلِ قَالَ ‏ "‏ لاَ، حَتَّى يَذُوقَ عُسَيْلَتَهَا كَمَا ذَاقَ الأَوَّلُ ‏"‏‏.‏\hadithno{5261}\hadithtrans{Narrated `Aisha:A man divorced his wife thrice (by expressing his decision to divorce her thrice), then she married another man who also divorced her. The Prophet (ﷺ) was asked if she could legally marry the first husband (or not). The Prophet (ﷺ) replied, "No, she cannot marry the first husband unless the second husband consummates his marriage with her, just as the first husband had done}}
\hadithdefcmd{bukhari}{5262}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا مُسْلِمٌ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَا اللَّهَ وَرَسُولَهُ، فَلَمْ يَعُدَّ ذَلِكَ عَلَيْنَا شَيْئًا‏.‏\hadithno{5262}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) gave us the option (to remain with him or to be divorced) and we selected Allah and His Apostle . So, giving us that option was not regarded as divorce}}
\hadithdefcmd{bukhari}{5263}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا عَامِرٌ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْخِيَرَةِ،، فَقَالَتْ خَيَّرَنَا النَّبِيُّ صلى الله عليه وسلم أَفَكَانَ طَلاَقًا قَالَ مَسْرُوقٌ لاَ أُبَالِي أَخَيَّرْتُهَا وَاحِدَةً أَوْ مِائَةً بَعْدَ أَنْ تَخْتَارَنِي‏.‏\hadithno{5263}\hadithtrans{Narrated Masruq:I asked `Aisha about the option: She said, "The Prophet (ﷺ) gave us the option. Do you think that option was considered as a divorce?" I said, "It matters little to me if I give my wife the option once or a hundred times after she has chosen me}}
\hadithdefcmd{bukhari}{5264}{وَقَالَ اللَّيْثُ عَنْ نَافِعٍ، كَانَ ابْنُ عُمَرَ إِذَا سُئِلَ عَمَّنْ طَلَّقَ ثَلاَثًا قَالَ لَوْ طَلَّقْتَ مَرَّةً أَوْ مَرَّتَيْنِ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَنِي بِهَذَا، فَإِنْ طَلَّقْتَهَا ثَلاَثًا حَرُمَتْ حَتَّى تَنْكِحَ زَوْجًا غَيْرَكَ‏.‏\hadithno{5264}\hadithtrans{Nafi' said:When Ibn 'Umar was asked about person who had given three divorces, he said, "Would that you gave one or two divorces, for the Prophet (ﷺ) ordered me to do so. If you give three divorces then she cannot be lawful for you until she has married another husband (and is divorced by him)}}
\hadithdefcmd{bukhari}{5265}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَلَّقَ رَجُلٌ امْرَأَتَهُ فَتَزَوَّجَتْ زَوْجًا غَيْرَهُ فَطَلَّقَهَا، وَكَانَتْ مَعَهُ مِثْلُ الْهُدْبَةِ فَلَمْ تَصِلْ مِنْهُ إِلَى شَىْءٍ تُرِيدُهُ، فَلَمْ يَلْبَثْ أَنْ طَلَّقَهَا فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ زَوْجِي طَلَّقَنِي، وَإِنِّي تَزَوَّجْتُ زَوْجًا غَيْرَهُ فَدَخَلَ بِي، وَلَمْ يَكُنْ مَعَهُ إِلاَّ مِثْلُ الْهُدْبَةِ فَلَمْ يَقْرَبْنِي إِلاَّ هَنَةً وَاحِدَةً، لَمْ يَصِلْ مِنِّي إِلَى شَىْءٍ، فَأَحِلُّ لِزَوْجِي الأَوَّلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلِّينَ لِزَوْجِكِ الأَوَّلِ حَتَّى يَذُوقَ الآخَرُ عُسَيْلَتَكِ، وَتَذُوقِي عُسَيْلَتَهُ ‏"‏‏.‏\hadithno{5265}\hadithtrans{Narrated `Aisha:A man divorced his wife and she married another man who proved to be impotent and divorced her. She could not get her satisfaction from him, and after a while he divorced her. Then she came to the Prophet and said, "O Allah's Messenger (ﷺ)! My first husband divorced me and then I married another man who entered upon me to consummate his marriage but he proved to be impotent and did not approach me except once during which he benefited nothing from me. Can I remarry my first husband in this case?" Allah's Messenger (ﷺ) said, "It is unlawful to marry your first husband till the other husband consummates his marriage with you}}
\hadithdefcmd{bukhari}{5266}{حَدَّثَنِي الْحَسَنُ بْنُ صَبَّاحٍ، سَمِعَ الرَّبِيعَ بْنَ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ إِذَا حَرَّمَ امْرَأَتَهُ لَيْسَ بِشَىْءٍ‏.‏ وَقَالَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏\hadithno{5266}\hadithtrans{Narrated Sa`id bin Jubair:that he heard Ibn `Abbas saying, "If a man makes his wife unlawful for him, it does not mean that she is divorced." He added, "Indeed in the Messenger of Allah , you have a good example to follow}}
\hadithdefcmd{bukhari}{5267}{حَدَّثَنِي الْحَسَنُ بْنُ مُحَمَّدِ بْنِ صَبَّاحٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ زَعَمَ عَطَاءٌ أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، يَقُولُ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ ابْنَةِ جَحْشٍ، وَيَشْرَبُ عِنْدَهَا عَسَلاً، فَتَوَاصَيْتُ أَنَا وَحَفْصَةُ أَنَّ أَيَّتَنَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ، أَكَلْتَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُمَا فَقَالَتْ لَهُ ذَلِكَ، فَقَالَ ‏"‏ لاَ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ ابْنَةِ جَحْشٍ وَلَنْ أَعُودَ لَهُ ‏"‏‏.‏ فَنَزَلَتْ ‏\{‏يَا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ‏\}‏ إِلَى ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ‏\}‏ لِعَائِشَةَ وَحَفْصَةَ ‏\{‏وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاً ‏"‏‏.‏\hadithno{5267}\hadithtrans{Narrated `Ubaid bin `Umar:I heard `Aisha saying, "The Prophet (ﷺ) used to stay for a long while with Zanab bint Jahsh and drink honey at her house. So Hafsa and I decided that if the Prophet (ﷺ) came to anyone of us, she should say him, "I detect the smell of Maghafir (a nasty smelling gum) in you. Have you eaten Maghafir?' " So the Prophet (ﷺ) visited one of them and she said to him similarly. The Prophet (ﷺ) said, "Never mind, I have taken some honey at the house of Zainab bint Jahsh, but I shall never drink of it anymore." So there was revealed: 'O Prophet ! Why do you ban (for you) that which Allah has made lawful for you . . . If you two (wives of Prophet) turn in repentance to Allah,' (66.1-4) addressing Aisha and Hafsa. 'When the Prophet (ﷺ) disclosed a matter in confidence to some of his wives.' (66.3) namely his saying: But I have taken some honey}}
\hadithdefcmd{bukhari}{5268}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ الْعَسَلَ وَالْحَلْوَاءَ، وَكَانَ إِذَا انْصَرَفَ مِنَ الْعَصْرِ دَخَلَ عَلَى نِسَائِهِ، فَيَدْنُو مِنْ إِحْدَاهُنَّ، فَدَخَلَ عَلَى حَفْصَةَ بِنْتِ عُمَرَ، فَاحْتَبَسَ أَكْثَرَ مَا كَانَ يَحْتَبِسُ، فَغِرْتُ فَسَأَلْتُ عَنْ ذَلِكَ فَقِيلَ لِي أَهْدَتْ لَهَا امْرَأَةٌ مِنْ قَوْمِهَا عُكَّةً مِنْ عَسَلٍ، فَسَقَتِ النَّبِيَّ صلى الله عليه وسلم مِنْهُ شَرْبَةً، فَقُلْتُ أَمَا وَاللَّهِ لَنَحْتَالَنَّ لَهُ‏.‏ فَقُلْتُ لِسَوْدَةَ بِنْتِ زَمْعَةَ إِنَّهُ سَيَدْنُو مِنْكِ، فَإِذَا دَنَا مِنْكِ فَقُولِي أَكَلْتَ مَغَافِيرَ فَإِنَّهُ سَيَقُولُ لَكِ لاَ‏.‏ فَقُولِي لَهُ مَا هَذِهِ الرِّيحُ الَّتِي أَجِدُ مِنْكَ فَإِنَّهُ سَيَقُولُ لَكِ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ فَقُولِي لَهُ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ‏.‏ وَسَأَقُولُ ذَلِكَ، وَقُولِي أَنْتِ يَا صَفِيَّةُ ذَاكِ‏.‏ قَالَتْ تَقُولُ سَوْدَةُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ قَامَ عَلَى الْبَابِ، فَأَرَدْتُ أَنْ أُبَادِيَهُ بِمَا أَمَرْتِنِي بِهِ فَرَقًا مِنْكِ، فَلَمَّا دَنَا مِنْهَا قَالَتْ لَهُ سَوْدَةُ يَا رَسُولَ اللَّهِ أَكَلْتَ مَغَافِيرَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَتْ فَمَا هَذِهِ الرِّيحُ الَّتِي أَجِدُ مِنْكَ‏.‏ قَالَ ‏"‏ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ ‏"‏‏.‏ فَقَالَتْ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ فَلَمَّا دَارَ إِلَىَّ قُلْتُ لَهُ نَحْوَ ذَلِكَ، فَلَمَّا دَارَ إِلَى صَفِيَّةَ قَالَتْ لَهُ مِثْلَ ذَلِكَ فَلَمَّا دَارَ إِلَى حَفْصَةَ قَالَتْ يَا رَسُولَ اللَّهِ أَلاَ أَسْقِيكَ مِنْهُ‏.‏ قَالَ ‏"‏ لاَ حَاجَةَ لِي فِيهِ ‏"‏‏.‏ قَالَتْ تَقُولُ سَوْدَةُ وَاللَّهِ لَقَدْ حَرَمْنَاهُ‏.‏ قُلْتُ لَهَا اسْكُتِي‏.‏\hadithno{5268}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) was fond of honey and sweet edible things and (it was his habit) that after finishing the `Asr prayer he would visit his wives and stay with one of them at that time. Once he went to Hafsa, the daughter of `Umar and stayed with her more than usual. I got jealous and asked the reason for that. I was told that a lady of her folk had given her a skin filled with honey as a present, and that she made a syrup from it and gave it to the Prophet (ﷺ) to drink (and that was the reason for the delay). I said, "By Allah we will play a trick on him (to prevent him from doing so)." So I said to Sa`da bint Zam`a "The Prophet (ﷺ) will approach you, and when he comes near you, say: 'Have you taken Maghafir (a bad-smelling gum)?' He will say, 'No.' Then say to him: 'Then what is this bad smell which i smell from you?' He will say to you, 'Hafsa made me drink honey syrup.' Then say: Perhaps the bees of that honey had sucked the juice of the tree of Al-`Urfut.' I shall also say the same. O you, Safiyya, say the same." Later Sa`da said, "By Allah, as soon as he (the Prophet (ﷺ) ) stood at the door, I was about to say to him what you had ordered me to say because I was afraid of you." So when the Prophet (ﷺ) came near Sa`da, she said to him, "O Allah's Messenger (ﷺ)! Have you taken Maghafir?" He said, "No." She said. "Then what is this bad smell which I detect on you?" He said, "Hafsa made me drink honey syrup." She said, "Perhaps its bees had sucked the juice of Al-`Urfut tree." When he came to me, I also said the same, and when he went to Safiyya, she also said the same. And when the Prophet (ﷺ) again went to Hafsa, she said, 'O Allah's Messenger (ﷺ)! Shall I give you more of that drink?" He said, "I am not in need of it." Sa`da said, "By Allah, we deprived him (of it)." I said to her, "Keep quiet}}
\hadithdefcmd{bukhari}{5269}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ عَنْ أُمَّتِي مَا حَدَّثَتْ بِهِ أَنْفُسَهَا، مَا لَمْ تَعْمَلْ أَوْ تَتَكَلَّمْ ‏"‏‏.‏ قَالَ قَتَادَةُ إِذَا طَلَّقَ فِي نَفْسِهِ فَلَيْسَ بِشَىْءٍ‏.‏\hadithno{5269}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah has forgiven my followers the evil thoughts that occur to their minds, as long as such thoughts are not put into action or uttered." And Qatada said, "If someone divorces his wife just in his mind, such an unuttered divorce has no effect.:}}
\hadithdefcmd{bukhari}{5270}{حَدَّثَنَا أَصْبَغُ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ أَتَى النَّبِيَّ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَقَالَ إِنَّهُ قَدْ زَنَى‏.‏ فَأَعْرَضَ عَنْهُ، فَتَنَحَّى لِشِقِّهِ الَّذِي أَعْرَضَ فَشَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ، فَدَعَاهُ فَقَالَ ‏ "‏ هَلْ بِكَ جُنُونٌ هَلْ أُحْصِنْتَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ فَأَمَرَ بِهِ أَنْ يُرْجَمَ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ جَمَزَ حَتَّى أُدْرِكَ بِالْحَرَّةِ فَقُتِلَ‏.‏\hadithno{5270}\hadithtrans{Narrated Jabir:A man from the tribe of Bani Aslam came to the Prophet (ﷺ) while he was in the mosque and said, "I have committed illegal sexual intercourse." The Prophet (ﷺ) turned his face to the other side. The man turned towards the side towards which the Prophet (ﷺ) had turned his face, and gave four witnesses against himself. On that the Prophet (ﷺ) called him and said, "Are you insane?" (He added), "Are you married?" The man said, 'Yes." On that the Prophet (ﷺ) ordered him to be stoned to the death in the Musalla (a praying place). When the stones hit him with their sharp edges and he fled, but he was caught at Al- Harra and then killed}}
\hadithdefcmd{bukhari}{5272}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ أَتَى رَجُلٌ مِنْ أَسْلَمَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الأَخِرَ قَدْ زَنَى ـ يَعْنِي نَفْسَهُ ـ فَأَعْرَضَ عَنْهُ فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الأَخِرَ قَدْ زَنَى فَأَعْرَضَ عَنْهُ فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ لَهُ ذَلِكَ فَأَعْرَضَ عَنْهُ فَتَنَحَّى لَهُ الرَّابِعَةَ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ دَعَاهُ فَقَالَ ‏"‏ هَلْ بِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏‏.‏ وَكَانَ قَدْ أُحْصِنَ‏.‏ وَعَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، قَالَ كُنْتُ فِيمَنْ رَجَمَهُ فَرَجَمْنَاهُ بِالْمُصَلَّى بِالْمَدِينَةِ، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ جَمَزَ حَتَّى أَدْرَكْنَاهُ بِالْحَرَّةِ، فَرَجَمْنَاهُ حَتَّى مَاتَ‏.‏\hadithno{5272}\hadithtrans{Narrated Abu Huraira:A man from Bani Aslam came to Allah's Messenger (ﷺ) while he was in the mosque and called (the Prophet (ﷺ) ) saying, "O Allah's Messenger (ﷺ)! I have committed illegal sexual intercourse." On that the Prophet (ﷺ) turned his face from him to the other side, whereupon the man moved to the side towards which the Prophet (ﷺ) had turned his face, and said, "O Allah's Messenger (ﷺ)! I have committed illegal sexual intercourse." The Prophet turned his face (from him) to the other side whereupon the man moved to the side towards which the Prophet (ﷺ) had turned his face, and repeated his statement. The Prophet (ﷺ) turned his face (from him) to the other side again. The man moved again (and repeated his statement) for the fourth time. So when the man had given witness four times against himself, the Prophet (ﷺ) called him and said, "Are you insane?" He replied, "No." The Prophet (ﷺ) then said (to his companions), "Go and stone him to death." The man was a married one. Jabir bin `Abdullah Al-Ansari said: I was one of those who stoned him. We stoned him at the Musalla (`Id praying place) in Medina. When the stones hit him with their sharp edges, he fled, but we caught him at Al-Harra and stoned him till he died}}
\hadithdefcmd{bukhari}{5273}{حَدَّثَنَا أَزْهَرُ بْنُ جَمِيلٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ،‏.‏ أَنَّ امْرَأَةَ، ثَابِتِ بْنِ قَيْسٍ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ ثَابِتُ بْنُ قَيْسٍ مَا أَعْتُبُ عَلَيْهِ فِي خُلُقٍ وَلاَ دِينٍ، وَلَكِنِّي أَكْرَهُ الْكُفْرَ فِي الإِسْلاَمِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْبَلِ الْحَدِيقَةَ وَطَلِّقْهَا تَطْلِيقَةً ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ لَا يُتَابَعُ فِيهِ عَنْ ابْنِ عَبَّاسٍ\hadithno{5273}\hadithtrans{Narrated Ibn `Abbas:The wife of Thabit bin Qais came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! I do not blame Thabit for defects in his character or his religion, but I, being a Muslim, dislike to behave in un-Islamic manner (if I remain with him)." On that Allah's Messenger (ﷺ) said (to her), "Will you give back the garden which your husband has given you (as Mahr)?" She said, "Yes." Then the Prophet (ﷺ) said to Thabit, "O Thabit! Accept your garden, and divorce her once}}
\hadithdefcmd{bukhari}{5274}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، أَنَّ أُخْتَ عَبْدِ اللَّهِ بْنِ أُبَىٍّ، بِهَذَا، وَقَالَ ‏ "‏ تَرُدِّينَ حَدِيقَتَهُ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ فَرَدَّتْهَا وَأَمَرَهُ يُطَلِّقْهَا‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ خَالِدٍ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَطَلِّقْهَا‏.‏\hadithno{5274}\hadithtrans{Narrated `Ikrima:The sister of `Abdullah bin Ubai narrated (the above narration, 197) with the addition that the Prophet (ﷺ) said to Thabit's wife, "Will you return his garden?" She said, "Yes," and returned it, and (then) the Prophet ordered Thabit to divorce her}}
\hadithdefcmd{bukhari}{5275}{وَعَنِ ابْنِ أَبِي تَمِيمَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ جَاءَتِ امْرَأَةُ ثَابِتِ بْنِ قَيْسٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَعْتُبُ عَلَى ثَابِتٍ فِي دِينٍ وَلاَ خُلُقٍ، وَلَكِنِّي لاَ أُطِيقُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏\hadithno{5275}\hadithtrans{Narrated Ibn `Abbas:The wife of Thabit bin Qais came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I do not blame Thabit for any defects in his character or his religion, but I cannot endure to live with him." On that Allah's Messenger (ﷺ) said, "Will you return his garden to him?" She said, "Yes}}
\hadithdefcmd{bukhari}{5276}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، حَدَّثَنَا قُرَادٌ أَبُو نُوحٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما قَالَ جَاءَتِ امْرَأَةُ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ مَا أَنْقِمُ عَلَى ثَابِتٍ فِي دِينٍ وَلاَ خُلُقٍ، إِلاَّ أَنِّي أَخَافُ الْكُفْرَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏‏.‏ فَقَالَتْ نَعَمْ‏.‏ فَرَدَّتْ عَلَيْهِ، وَأَمَرَهُ فَفَارَقَهَا‏.‏\hadithno{5276}\hadithtrans{Narrated Ibn `Abbas:The wife of Thabit bin Qais bin Shammas came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! I do not blame Thabit for any defects in his character or his religion, but I am afraid that I (being a Muslim) may become unthankful for Allah's Blessings." On that, Allah's Messenger (ﷺ) said (to her), 'Will you return his garden to him?" She said, "Yes." So she returned his garden to him and the Prophet (ﷺ) told him to divorce her}}
\hadithdefcmd{bukhari}{5277}{حَدَّثَنَا سُلَيْمَانُ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، أَنَّ جَمِيلَةَ، فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{5277}\hadithtrans{Narrated `Ikrima:that Jamila... Then he related the whole ,Hadith, (i.e)}}
\hadithdefcmd{bukhari}{5278}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ بَنِي الْمُغِيرَةِ اسْتَأْذَنُوا فِي أَنْ يَنْكِحَ عَلِيٌّ ابْنَتَهُمْ، فَلاَ آذَنُ ‏"‏‏.‏\hadithno{5278}\hadithtrans{Narrated Al-Miswar bin Makhrama Az-Zuhri:I heard the Prophet (ﷺ) saying, "Banu Al-Mughira have asked my leave to let `Ali marry their daughter, but I give no leave to this effect}}
\hadithdefcmd{bukhari}{5279}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ، إِحْدَى السُّنَنِ أَنَّهَا أُعْتِقَتْ، فَخُيِّرَتْ فِي زَوْجِهَا‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْبُرْمَةُ تَفُورُ بِلَحْمٍ، فَقُرِّبَ إِلَيْهِ خُبْزٌ وَأُدْمٌ مِنْ أُدْمِ الْبَيْتِ فَقَالَ ‏"‏ أَلَمْ أَرَ الْبُرْمَةَ فِيهَا لَحْمٌ ‏"‏‏.‏ قَالُوا بَلَى، وَلَكِنْ ذَلِكَ لَحْمٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ، وَأَنْتَ لاَ تَأْكُلُ الصَّدَقَةَ‏.‏ قَالَ ‏"‏ عَلَيْهَا صَدَقَةٌ، وَلَنَا هَدِيَّةٌ ‏"‏‏.‏\hadithno{5279}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Three traditions were established concerning situations in which Barra was involved: When she was manumitted, she was given the option to keep her husband or leave him; Allah's Messenger (ﷺ) said, "The wala is for the one who manumits, Once Allah's Messenger (ﷺ) entered the house while some meat was being cooked in a pot, but only bread and some soup of the house were placed before, him. He said, "Don't I see the pot containing meat?" They said, "Yes, but that meat was given to Barira in charity (by someone), and you do not eat what it given in charity."The Prophet (ﷺ) said "That meat is alms for her, but for us it is a present}}
\hadithdefcmd{bukhari}{5280}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، وَهَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَأَيْتُهُ عَبْدًا يَعْنِي زَوْجَ بَرِيرَةَ‏.‏\hadithno{5280}\hadithtrans{Narrated Ibn `Abbas:I saw him as a slave, (namely, Barira's husband)}}
\hadithdefcmd{bukhari}{5281}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ذَاكَ مُغِيثٌ عَبْدُ بَنِي فُلاَنٍ ـ يَعْنِي زَوْجَ بَرِيرَةَ ـ كَأَنِّي أَنْظُرُ إِلَيْهِ يَتْبَعُهَا فِي سِكَكِ الْمَدِينَةِ، يَبْكِي عَلَيْهَا‏.‏\hadithno{5281}\hadithtrans{Narrated Ibn `Abbas:That was Mughith, the slave of Bani so-and-so, i.e., Barira's husband as if I am now looking at him following her (Barira) along the streets of Medina}}
\hadithdefcmd{bukhari}{5282}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا أَسْوَدَ يُقَالُ لَهُ مُغِيثٌ، عَبْدًا لِبَنِي فُلاَنٍ، كَأَنِّي أَنْظُرُ إِلَيْهِ يَطُوفُ وَرَاءَهَا فِي سِكَكِ الْمَدِينَةِ‏.‏\hadithno{5282}\hadithtrans{Narrated Ibn `Abbas:Barira's husband was a black slave called Mughith, the slave of Bani so-and-so-- as if I am seeing him now, walking behind her along the streets of Medina}}
\hadithdefcmd{bukhari}{5283}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ زَوْجَ، بَرِيرَةَ كَانَ عَبْدًا يُقَالُ لَهُ مُغِيثٌ كَأَنِّي أَنْظُرُ إِلَيْهِ يَطُوفُ خَلْفَهَا يَبْكِي، وَدُمُوعُهُ تَسِيلُ عَلَى لِحْيَتِهِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِعَبَّاسٍ ‏"‏ يَا عَبَّاسُ أَلاَ تَعْجَبُ مِنْ حُبِّ مُغِيثٍ بَرِيرَةَ، وَمِنْ بُغْضِ بَرِيرَةَ مُغِيثًا ‏"‏‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ رَاجَعْتِهِ ‏"‏‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ تَأْمُرُنِي قَالَ ‏"‏ إِنَّمَا أَنَا أَشْفَعُ ‏"‏‏.‏ قَالَتْ لاَ حَاجَةَ لِي فِيهِ‏.‏\hadithno{5283}\hadithtrans{Narrated Ibn `Abbas:Barira's husband was a slave called Mughith, as if I am seeing him now, going behind Barira and weeping with his tears flowing down his beard. The Prophet (ﷺ) said to `Abbas, "O `Abbas ! are you not astonished at the love of Mughith for Barira and the hatred of Barira for Mughith?" The Prophet (ﷺ) then said to Barira, "Why don't you return to him?" She said, "O Allah's Messenger (ﷺ)! Do you order me to do so?" He said, "No, I only intercede for him." She said, "I am not in need of him}}
\hadithdefcmd{bukhari}{5284}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، أَنَّ عَائِشَةَ، أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ، فَأَبَى مَوَالِيهَا إِلاَّ أَنْ يَشْتَرِطُوا الْوَلاَءَ، فَذَكَرَتْ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ وَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِلَحْمٍ فَقِيلَ إِنَّ هَذَا مَا تُصُدِّقَ عَلَى بَرِيرَةَ، فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ، وَلَنَا هَدِيَّةٌ ‏"‏‏. حَدَّثَنَا آدَمُ حَدَّثَنَا شُعْبَةُ وَزَادَ فَخُيِّرَتْ مِنْ زَوْجِهَا‏.‏\hadithno{5284}\hadithtrans{Narrated Al-Aswad:Aisha intended to buy Barira, but her masters stipulated that her wala wound be for them. Aisha mentioned that to the Prophet (ﷺ) who said (to `Aisha), "Buy and manumit her, for the wala is for the one who manumits." Once some meat was brought to the Prophet (ﷺ) and was said, "This meat was given in charity to Barira. " The Prophet (ﷺ) said, "It is an object of charity for Barira and a gift for us." Narrated Adam: Shu`ba related the same Hadith and added: Barira was given the option regarding her husband}}
\hadithdefcmd{bukhari}{5285}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ إِذَا سُئِلَ عَنْ نِكَاحِ النَّصْرَانِيَّةِ، وَالْيَهُودِيَّةِ، قَالَ إِنَّ اللَّهَ حَرَّمَ الْمُشْرِكَاتِ عَلَى الْمُؤْمِنِينَ، وَلاَ أَعْلَمُ مِنَ الإِشْرَاكِ شَيْئًا أَكْبَرَ مِنْ أَنْ تَقُولَ الْمَرْأَةُ رَبُّهَا عِيسَى، وَهْوَ عَبْدٌ مِنْ عِبَادِ اللَّهِ‏.‏\hadithno{5285}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar was asked about marrying a Christian lady or a Jewess, he would say: "Allah has made it unlawful for the believers to marry ladies who ascribe partners in worship to Allah, and I do not know of a greater thing, as regards to ascribing partners in worship, etc. to Allah, than that a lady should say that Jesus is her Lord although he is just one of Allah's slaves}}
\hadithdefcmd{bukhari}{5286}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، وَقَالَ، عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ، كَانَ الْمُشْرِكُونَ عَلَى مَنْزِلَتَيْنِ مِنَ النَّبِيِّ صلى الله عليه وسلم وَالْمُؤْمِنِينَ، كَانُوا مُشْرِكِي أَهْلِ حَرْبٍ يُقَاتِلُهُمْ وَيُقَاتِلُونَهُ، وَمُشْرِكِي أَهْلِ عَهْدٍ لاَ يُقَاتِلُهُمْ وَلاَ يُقَاتِلُونَهُ، وَكَانَ إِذَا هَاجَرَتِ امْرَأَةٌ مِنْ أَهْلِ الْحَرْبِ لَمْ تُخْطَبْ حَتَّى تَحِيضَ وَتَطْهُرَ، فَإِذَا طَهُرَتْ حَلَّ لَهَا النِّكَاحُ، فَإِنْ هَاجَرَ زَوْجُهَا قَبْلَ أَنْ تَنْكِحَ رُدَّتْ إِلَيْهِ، وَإِنْ هَاجَرَ عَبْدٌ مِنْهُمْ أَوْ أَمَةٌ فَهُمَا حُرَّانِ وَلَهُمَا مَا لِلْمُهَاجِرِينَ‏.‏ ثُمَّ ذَكَرَ مِنْ أَهْلِ الْعَهْدِ مِثْلَ حَدِيثِ مُجَاهِدٍ وَإِنْ هَاجَرَ عَبْدٌ أَوْ أَمَةٌ لِلْمُشْرِكِينَ أَهْلِ الْعَهْدِ لَمْ يُرَدُّوا، وَرُدَّتْ أَثْمَانُهُمْ‏.‏\hadithno{5286}\hadithtrans{Narrated Ibn 'Abbas: The pagans were of two kinds as regards their relationship to the Prophet and the Believers. Some of them were those with whom the Prophet was at war and used to fight against, and they used to fight him; the others were those with whom the Prophet (ﷺ) made a treaty, and neither did the Prophet (ﷺ) fight them, nor did they fight him. If a lady from the first group of pagans emigrated towards the Muslims, her hand would not be asked in marriage unless she got the menses and then became clean. When she became clean, it would be lawful for her to get married, and if her husband emigrated too before she got married, then she would be returned to him. If any slave or female slave emigrated from them to the Muslims, then they would be considered free persons (not slaves) and they would have the same rights as given to other emigrants. The narrator then mentioned about the pagans involved with the Muslims in a treaty, the same as occurs in Mujahid's narration. If a male slave or a female slave emigrated from such pagans as had made a treaty with the Muslims, they would not be returned, but their prices would be paid (to the pagans)}}
\hadithdefcmd{bukhari}{5287}{وَقَالَ عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ، كَانَتْ قَرِيبَةُ بِنْتُ أَبِي أُمَيَّةَ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ فَطَلَّقَهَا، فَتَزَوَّجَهَا مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ، وَكَانَتْ أُمُّ الْحَكَمِ ابْنَةُ أَبِي سُفْيَانَ تَحْتَ عِيَاضِ بْنِ غَنْمٍ الْفِهْرِيِّ فَطَلَّقَهَا، فَتَزَوَّجَهَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ الثَّقَفِيُّ‏.‏\hadithno{5287}\hadithtrans{Narrated Ibn 'Abbas:Qariba, The daughter of Abi Umaiyya, was the wife of 'Umar bin Al-Khattab. 'Umar divorced her and then Mu'awiyya bin Abi Sufyan married her. Similarly, Um Al-Hakam, the daughter of Abi Sufyan was the wife of 'Iyad bin Ghanm Al-Fihri. He divorced her and then 'Abdullah bin 'Uthman Al-Thaqafi married her}}
\hadithdefcmd{bukhari}{5288}{حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ،‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ الْمُنْذِرِ حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَتِ الْمُؤْمِنَاتُ إِذَا هَاجَرْنَ إِلَى النَّبِيِّ صلى الله عليه وسلم يَمْتَحِنُهُنَّ بِقَوْلِ اللَّهِ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ‏\}‏ إِلَى آخِرِ الآيَةِ قَالَتْ عَائِشَةُ فَمَنْ أَقَرَّ بِهَذَا الشَّرْطِ مِنَ الْمُؤْمِنَاتِ فَقَدْ أَقَرَّ بِالْمِحْنَةِ، فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَقْرَرْنَ بِذَلِكَ مِنْ قَوْلِهِنَّ قَالَ لَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْطَلِقْنَ فَقَدْ بَايَعْتُكُنَّ ‏"‏، لاَ وَاللَّهِ مَا مَسَّتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَدَ امْرَأَةٍ قَطُّ، غَيْرَ أَنَّهُ بَايَعَهُنَّ بِالْكَلاَمِ، وَاللَّهِ مَا أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النِّسَاءِ إِلاَّ بِمَا أَمَرَهُ اللَّهُ يَقُولُ لَهُنَّ إِذَا أَخَذَ عَلَيْهِنَّ ‏"‏ قَدْ بَايَعْتُكُنَّ ‏"‏‏.‏ كَلاَمًا‏.‏\hadithno{5288}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) When believing women came to the Prophet (ﷺ) as emigrants, he used to test them in accordance with the order of Allah. 'O you who believe! When believing women come to you as emigrants, examine them . . .' (60.10) So if anyone of those believing women accepted the above mentioned conditions, she accepted the conditions of faith. When they agreed on those conditions and confessed that with their tongues, Allah's Messenger (ﷺ) would say to them, "Go, I have accepted your oath of allegiance (for Islam). By Allah, and hand of Allah's Messenger (ﷺ) never touched the hand of any woman, but he only used to take their pledge of allegiance orally. By Allah, Allah's Messenger (ﷺ) did not take the pledge of allegiance of the women except in accordance with what Allah had ordered him. When he accepted their pledge of allegiance he would say to them, "I have accepted your oath of allegiance}}
\hadithdefcmd{bukhari}{5289}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، عَنْ أَخِيهِ، عَنْ سُلَيْمَانَ، عَنْ حُمَيْدٍ الطَّوِيلِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ، وَكَانَتِ انْفَكَّتْ رِجْلُهُ فَأَقَامَ فِي مَشْرُبَةٍ لَهُ تِسْعًا وَعِشْرِينَ، ثُمَّ نَزَلَ فَقَالُوا يَا رَسُولَ اللَّهِ آلَيْتَ شَهْرًا‏.‏ فَقَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏‏.‏\hadithno{5289}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) took an oath that he would abstain from his wives, and at that time his leg had been sprained (dislocated). So he stayed in the Mashruba (an attic room) of his for 29 days. Then he came down, and they (the people) said, "O Allah's Messenger (ﷺ)! You took an oath to abstain from your wives for one month." He said, "The month is of twenty nine days}}
\hadithdefcmd{bukhari}{5290}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، رضى الله عنهما كَانَ يَقُولُ فِي الإِيلاَءِ الَّذِي سَمَّى اللَّهُ لاَ يَحِلُّ لأَحَدٍ بَعْدَ الأَجَلِ إِلاَّ أَنْ يُمْسِكَ بِالْمَعْرُوفِ، أَوْ يَعْزِمَ بِالطَّلاَقِ، كَمَا أَمَرَ اللَّهُ عَزَّ وَجَلَّ‏.‏\hadithno{5290}\hadithtrans{Narrated Nafi`:Ibn `Umar used to say about the Ila (which Allah defined (in the Holy Book), "If the period of Ila expires, then the husband has either to retain his wife in a handsome manner or to divorce her as Allah has ordered}}
\hadithdefcmd{bukhari}{5291}{وَقَالَ لِي إِسْمَاعِيلُ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، إِذَا مَضَتْ أَرْبَعَةُ أَشْهُرٍ يُوقَفُ حَتَّى يُطَلِّقَ، وَلاَ يَقَعُ عَلَيْهِ الطَّلاَقُ حَتَّى يُطَلِّقَ‏.‏ وَيُذْكَرُ ذَلِكَ عَنْ عُثْمَانَ وَعَلِيٍّ وَأَبِي الدَّرْدَاءِ وَعَائِشَةَ وَاثْنَىْ عَشَرَ رَجُلاً مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5291}\hadithtrans{Ibn `Umar added:"When the period of four months has expired, the husband should be put in prison so that he should divorce his wife, but the divorce does not occur unless the husband himself declares it. This has been mentioned by `Uthman, `Ali, Abu Ad-Darda, `Aisha and twelve other companions of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{5292}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ ضَالَّةِ الْغَنَمِ فَقَالَ ‏"‏ خُذْهَا، فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ وَسُئِلَ عَنْ ضَالَّةِ الإِبِلِ، فَغَضِبَ وَاحْمَرَّتْ وَجْنَتَاهُ، وَقَالَ ‏"‏ مَا لَكَ وَلَهَا، مَعَهَا الْحِذَاءُ وَالسِّقَاءُ، تَشْرَبُ الْمَاءَ، وَتَأْكُلُ الشَّجَرَ، حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏‏.‏ وَسُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ اعْرِفْ وِكَاءَهَا وَعِفَاصَهَا، وَعَرِّفْهَا سَنَةً، فَإِنْ جَاءَ مَنْ يَعْرِفُهَا، وَإِلاَّ فَاخْلِطْهَا بِمَالِكَ ‏"‏‏.‏ قَالَ سُفْيَانُ فَلَقِيتُ رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ ـ قَالَ سُفْيَانُ وَلَمْ أَحْفَظْ عَنْهُ شَيْئًا غَيْرَ هَذَا ـ فَقُلْتُ أَرَأَيْتَ حَدِيثَ يَزِيدَ مَوْلَى الْمُنْبَعِثِ فِي أَمْرِ الضَّالَّةِ، هُوَ عَنْ زَيْدِ بْنِ خَالِدٍ قَالَ نَعَمْ‏.‏ قَالَ يَحْيَى وَيَقُولُ رَبِيعَةُ عَنْ يَزِيدَ مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ‏.‏ قَالَ سُفْيَانُ فَلَقِيتُ رَبِيعَةَ فَقُلْتُ لَهُ‏.‏\hadithno{5292}\hadithtrans{Narrated Yazid:(the Maula of Munba'ith) The Prophet (ﷺ) was asked regarding the case of a lost sheep. He said, "You should take it, because it is for you, or for your brother, or for the wolf." Then he was asked about a lost camel. He got angry and his face became red and he said (to the questioner), "You have nothing to do with it; it has its feet and its water container with it; it can go on drinking water and eating trees till its owner meets it." And then the Prophet (ﷺ) was asked about a Luqata (money found by somebody). He said, "Remember and recognize its tying material and its container, and make public announcement about it for one year. If somebody comes and identifies it (then give it to him), otherwise add it to your property}}
\hadithdefcmd{bukhari}{5293}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَعِيرِهِ، وَكَانَ كُلَّمَا أَتَى عَلَى الرُّكْنِ أَشَارَ إِلَيْهِ، وَكَبَّرَ‏.‏ وَقَالَتْ زَيْنَبُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فُتِحَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏‏.‏ وَعَقَدَ تِسْعِينَ‏.‏\hadithno{5293}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) performed the Tawaf (around the Ka`ba while riding his camel, and every time he reached the corner (of the Black Stone) he pointed at it with his hand and said, "Allahu Akbar." (Zainab said: The Prophet (ﷺ) said, "An opening has been made in the wall of Gog and Magog like this and this," forming the number 90 (with his thumb and index finger)}}
\hadithdefcmd{bukhari}{5294}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَلَمَةُ بْنُ عَلْقَمَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ فِي الْجُمُعَةِ سَاعَةٌ لاَ يُوَافِقُهَا مُسْلِمٌ قَائِمٌ يُصَلِّي، فَسَأَلَ اللَّهَ خَيْرًا، إِلاَّ أَعْطَاهُ ‏"‏‏.‏ وَقَالَ بِيَدِهِ، وَوَضَعَ أَنْمَلَتَهُ عَلَى بَطْنِ الْوُسْطَى وَالْخِنْصَرِ‏.‏ قُلْنَا يُزَهِّدُهَا‏.‏\hadithno{5294}\hadithtrans{Narrated Abu Huraira: Abul Qasim (the Prophet (ﷺ) ) said, "There is an hour (or a moment) of particular significance on Friday. If it happens that a Muslim is offering a prayer and invoking Allah for some good at that very moment, Allah will grant him his request." (The sub-narrator placed the top of his finger on the palm of the other hand between the middle finger and the little one)}}
\hadithdefcmd{bukhari}{5295}{وَقَالَ الأُوَيْسِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ شُعْبَةَ بْنِ الْحَجَّاجِ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ عَدَا يَهُودِيٌّ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى جَارِيَةٍ، فَأَخَذَ أَوْضَاحًا كَانَتْ عَلَيْهَا وَرَضَخَ رَأْسَهَا، فَأَتَى بِهَا أَهْلُهَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْىَ فِي آخِرِ رَمَقٍ، وَقَدْ أُصْمِتَتْ، فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَتَلَكِ فُلاَنٌ ‏"‏‏.‏ لِغَيْرِ الَّذِي قَتَلَهَا، فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ، قَالَ فَقَالَ لِرَجُلٍ آخَرَ غَيْرِ الَّذِي قَتَلَهَا، فَأَشَارَتْ أَنْ لاَ، فَقَالَ ‏"‏ فَفُلاَنٌ ‏"‏‏.‏ لِقَاتِلِهَا فَأَشَارَتْ أَنْ نَعَمْ، فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُضِخَ رَأْسُهُ بَيْنَ حَجَرَيْنِ‏.‏\hadithno{5295}\hadithtrans{Narrated Anas bin Malik: During the lifetime of Allah's Messenger (ﷺ) a Jew attacked a girl and took some silver ornaments she was wearing and crushed her head. Her relative brought her to the Prophet (ﷺ) while she was in her last breaths, and she was unable to speak. Allah's Messenger (ﷺ) asked her, "Who has hit you? so-and-so?", mentioning somebody other than her murderer. She moved her head, indicating denial. The Prophet (ﷺ) mentioned another person other than the murderer, and she again moved her head indicating denial. Then he asked, "Was it so-and-so?", mentioning the name of her killer. She nodded, agreeing. Then Allah's Messenger (ﷺ); ordered that the head of that Jew be crushed between two stones}}
\hadithdefcmd{bukhari}{5296}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْفِتْنَةُ مِنْ هَا هُنَا ‏"‏‏.‏ وَأَشَارَ إِلَى الْمَشْرِقِ‏.‏\hadithno{5296}\hadithtrans{Narrated Ibn `Umar:I heard the Prophet (ﷺ) saying, "Afflictions will emerge from here," pointing towards the East}}
\hadithdefcmd{bukhari}{5297}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ كُنَّا فِي سَفَرٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ لِرَجُلٍ ‏"‏ انْزِلْ فَاجْدَحْ لِي ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَوْ أَمْسَيْتَ‏.‏ ثُمَّ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَوْ أَمْسَيْتَ إِنَّ عَلَيْكَ نَهَارًا‏.‏ ثُمَّ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ ‏"‏‏.‏ فَنَزَلَ فَجَدَحَ لَهُ فِي الثَّالِثَةِ، فَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ أَوْمَأَ بِيَدِهِ إِلَى الْمَشْرِقِ فَقَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ قَدْ أَقْبَلَ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏\hadithno{5297}\hadithtrans{Narrated `Abdullah bin Abi A'ufa:We were with Allah's Messenger (ﷺ) on a journey, and when the sun set, he said to a man, "Get down and prepare a drink of Sawiq for me." The man said, "O Allah's Messenger (ﷺ)! Will you wait till it is evening?" Allah's Messenger (ﷺ) again said, "Get down and prepare a drink of Sawiq." The man said, "O Allah's Apostle! Will you wait till it is evening, for it is still daytime. " The Prophet (ﷺ) again said, "Get down and prepare a drink of Sawiq." So the third time the man got down and prepared a drink of sawiq for him. Allah's Messenger (ﷺ) drank thereof and pointed with his hand towards the East, saying, "When you see the night falling from this side, then a fasting person should break his fast}}
\hadithdefcmd{bukhari}{5298}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعَنَّ أَحَدًا مِنْكُمْ نِدَاءُ بِلاَلٍ ـ أَوْ قَالَ أَذَانُهُ ـ مِنْ سَحُورِهِ، فَإِنَّمَا يُنَادِي أَوْ قَالَ يُؤَذِّنُ لِيَرْجِعَ قَائِمُكُمْ ‏"‏‏.‏ وَلَيْسَ أَنْ يَقُولَ كَأَنَّهُ يَعْنِي الصُّبْحَ أَوِ الْفَجْرَ، وَأَظْهَرَ يَزِيدُ يَدَيْهِ ثُمَّ مَدَّ إِحْدَاهُمَا مِنَ الأُخْرَى‏.‏\hadithno{5298}\hadithtrans{Narrated 'Abdullah bin Mas'ud: The Prophet (ﷺ) said, "The call (or the Adhan) of Bilal should not stop you from taking the Suhur-meals for Bilal calls (or pronounces the Adhan) so that the one who is offering the night prayer should take a rest, and he does not indicate the daybreak or dawn." The narrator, Yazid, described (how dawn breaks) by stretching out his hands and then separating them wide apart}}
\hadithdefcmd{bukhari}{5299}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْبَخِيلِ وَالْمُنْفِقِ كَمَثَلِ رَجُلَيْنِ عَلَيْهِمَا جُبَّتَانِ مِنْ حَدِيدٍ، مِنْ لَدُنْ ثَدْيَيْهِمَا إِلَى تَرَاقِيهِمَا، فَأَمَّا الْمُنْفِقُ فَلاَ يُنْفِقُ شَيْئًا إِلاَّ مَادَّتْ عَلَى جِلْدِهِ حَتَّى تُجِنَّ بَنَانَهُ وَتَعْفُوَ أَثَرَهُ، وَأَمَّا الْبَخِيلُ فَلاَ يُرِيدُ يُنْفِقُ إِلاَّ لَزِمَتْ كُلُّ حَلْقَةٍ مَوْضِعَهَا، فَهْوَ يُوسِعُهَا فَلاَ تَتَّسِعُ ‏"‏‏.‏ وَيُشِيرُ بِإِصْبَعِهِ إِلَى حَلْقِهِ‏.‏\hadithno{5299}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, The example of a miser and a generous person is like that of two persons wearing iron cloaks from the breast upto the neck When the generous person spends, the iron cloak enlarges and spread over his skin so much so that it covers his fingertips and obliterates his tracks. As for the miser, as soon as he thinks of spending every ring of the iron cloak sticks to its place (against his body) and he tries to expand it, but it does not expand. The Prophet (ﷺ) pointed with his hand towards his throat}}
\hadithdefcmd{bukhari}{5300}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ دُورِ الأَنْصَارِ ‏"‏‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ بَنُو النَّجَّارِ، ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو عَبْدِ الأَشْهَلِ، ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ، ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو سَاعِدَةَ ‏"‏‏.‏ ثُمَّ قَالَ بِيَدِهِ، فَقَبَضَ أَصَابِعَهُ، ثُمَّ بَسَطَهُنَّ كَالرَّامِي بِيَدِهِ ثُمَّ قَالَ ‏"‏ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏‏.‏\hadithno{5300}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "Shall I tell you of the best families among the Ansar?" They (the people) said, "Yes, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "The best are Banu- An-Najjar, and after them are Banu `Abdil Ash-hal, and after them are Banu Al-Harith bin Al-Khazraj, and after them are Banu Sa`ida." The Prophet (ﷺ) then moved his hand by closing his fingers and then opening them like one throwing something, and then said, "Anyhow, there is good in all the families of the Ansar}}
\hadithdefcmd{bukhari}{5301}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ أَبُو حَازِمٍ سَمِعْتُهُ مِنْ، سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَذِهِ مِنْ هَذِهِ أَوْ كَهَاتَيْنِ ‏"‏‏.‏ وَقَرَنَ بَيْنَ السَّبَّابَةِ وَالْوُسْطَى‏.‏\hadithno{5301}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:(a companion of Allah's Messenger (ﷺ)) Allah's Messenger (ﷺ), holding out his middle and index fingers, said, "My advent and the Hour's are like this (or like these)," namely, the period between his era and the Hour is like the distance between those two fingers, i.e., very short}}
\hadithdefcmd{bukhari}{5302}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا جَبَلَةُ بْنُ سُحَيْمٍ، سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ يَعْنِي ثَلاَثِينَ، ثُمَّ قَالَ ‏"‏ وَهَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ يَعْنِي تِسْعًا وَعِشْرِينَ يَقُولُ، مَرَّةً ثَلاَثِينَ وَمَرَّةً تِسْعًا وَعِشْرِينَ‏.‏\hadithno{5302}\hadithtrans{Narrated Ibn `Umar:The Prophet (holding out his ten fingers thrice), said, "The month is thus and thus and thus," namely thirty days. Then (holding out his ten fingers twice and then nine fingers), he said, "It may be thus and thus and thus," namely twenty nine days. He meant once thirty days and once twenty nine days}}
\hadithdefcmd{bukhari}{5303}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ وَأَشَارَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ نَحْوَ الْيَمَنِ ‏ "‏ الإِيمَانُ هَا هُنَا ـ مَرَّتَيْنِ ـ أَلاَ وَإِنَّ الْقَسْوَةَ وَغِلَظَ الْقُلُوبِ فِي الْفَدَّادِينَ حَيْثُ يَطْلُعُ قَرْنَا الشَّيْطَانِ رَبِيعَةَ وَمُضَرَ ‏"‏‏.‏\hadithno{5303}\hadithtrans{Narrated Abu Masud:The Prophet (ﷺ) pointed with his hand towards Yemen and said twice, "Faith is there," and then pointed towards the East, and said, "Verily, sternness and mercilessness are the qualities of those who are busy with their camels and pay no attention to their religion, where the two sides of the head of Satan will appear," namely, the tribes of Rabl'a and Muqar}}
\hadithdefcmd{bukhari}{5304}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا وَكَافِلُ الْيَتِيمِ فِي الْجَنَّةِ هَكَذَا ‏"‏‏.‏ وَأَشَارَ بِالسَّبَّابَةِ وَالْوُسْطَى، وَفَرَّجَ بَيْنَهُمَا شَيْئًا‏.‏\hadithno{5304}\hadithtrans{Narrated Sahl:Allah's Messenger (ﷺ) said, "I and the one who looks after an orphan will be like this in Paradise," showing his middle and index fingers and separating them}}
\hadithdefcmd{bukhari}{5305}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ وُلِدَ لِي غُلاَمٌ أَسْوَدُ‏.‏ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ مَا أَلْوَانُهَا ‏"‏‏.‏ قَالَ حُمْرٌ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَأَنَّى ذَلِكَ ‏"‏‏.‏ قَالَ لَعَلَّهُ نَزَعَهُ عِرْقٌ‏.‏ قَالَ ‏"‏ فَلَعَلَّ ابْنَكَ هَذَا نَزَعَهُ ‏"‏‏.‏\hadithno{5305}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! A black child has been born for me." The Prophet asked him, "Have you got camels?" The man said, "Yes." The Prophet (ﷺ) asked him, "What color are they?" The man replied, "Red." The Prophet (ﷺ) said, "Is there a grey one among them?' The man replied, "Yes." The Prophet (ﷺ) said, "Whence comes that?" He said, "May be it is because of heredity." The Prophet (ﷺ) said, "May be your latest son has this color because of heredity}}
\hadithdefcmd{bukhari}{5306}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلُ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَجُلاً مِنَ الأَنْصَارِ قَذَفَ امْرَأَتَهُ فَأَحْلَفَهُمَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ فَرَّقَ بَيْنَهُمَا‏.‏\hadithno{5306}\hadithtrans{Narrated `Abdullah:An Ansari man accused his wife (of committing illegal sexual intercourse). The Prophet (ﷺ) made both of them takes the oath of Lian, and separated them from each other (by divorce)}}
\hadithdefcmd{bukhari}{5307}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامِ بْنِ حَسَّانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ هِلاَلَ بْنَ أُمَيَّةَ، قَذَفَ امْرَأَتَهُ، فَجَاءَ فَشَهِدَ وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ ثُمَّ قَامَتْ فَشَهِدَتْ‏.‏\hadithno{5307}\hadithtrans{Narrated Ibn `Abbas:Hilal bin Umaiyya accused his wife of illegal sexual intercourse and came to the Prophet (ﷺ) to bear witness (against her), (taking the oath of Lian). The Prophet (ﷺ) was saying, "Allah knows that either of you is a liar. Will anyone of you repent (to Allah)?" Then the lady got up and gave her witness}}
\hadithdefcmd{bukhari}{5308}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ عُوَيْمِرًا الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ الأَنْصَارِيِّ فَقَالَ لَهُ يَا عَاصِمُ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ، أَمْ كَيْفَ يَفْعَلُ سَلْ لِي يَا عَاصِمُ عَنْ ذَلِكَ‏.‏ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا، حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَهُ عُوَيْمِرٌ فَقَالَ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمٌ لِعُوَيْمِرٍ لَمْ تَأْتِنِي بِخَيْرٍ، قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتُهُ عَنْهَا‏.‏ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَهُ عَنْهَا‏.‏ فَأَقْبَلَ عُوَيْمِرٌ حَتَّى جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أُنْزِلَ فِيكَ وَفِي صَاحِبَتِكَ فَاذْهَبْ فَأْتِ بِهَا ‏"‏‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَا مِنْ تَلاَعُنِهِمَا قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا‏.‏ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانَتْ سُنَّةَ الْمُتَلاَعِنَيْنِ‏.‏\hadithno{5308}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:'Uwaimir Al-Ajlani came to `Asim bin Ad Al-Ansari and said to him, "O `Asim! Suppose a man saw another man with his wife, would he kill him whereupon you would kill him; or what should he do? Please, O `Asim, ask about this on my behalf." `Asim asked Allah's Messenger (ﷺ) about it. Allah's Messenger (ﷺ), disliked that question and considered it disgraceful. What `Asim heard from Allah's Messenger (ﷺ) was hard on him. When `Asim returned to his family, 'Uwaimir came to him and said, "O `Asim! What did Allah's Messenger (ﷺ). say to you?" `Asim said to 'Uwaimir, "You never bring me any good. Allah's Messenger (ﷺ) disliked the problem which I asked him about." 'Uwaimir said, "By Allah, I will not give up this matter until I ask the Prophet (ﷺ) about it." So 'Uwaimir proceeded till he came to Allah's Messenger (ﷺ) in the midst of people, and said, "O Allah's Messenger (ﷺ)! If a man sees another man with his wife, would he kill him, whereupon you would kill him, or what should he do?" Allah's Messenger (ﷺ) said, "Allah has revealed some decree as regards you and your wives case. Go and bring her." So they carried out the process of Lian while I was present among the people with Allah's Messenger (ﷺ). When they had finished their Lian, 'Uwaimir said, "O Allah's Messenger (ﷺ)! If I should now keep her with me as a wife, then I have told a lie." So he divorced her thrice before Allah's Messenger (ﷺ) ordered him. (Ibn Shihab said: So divorce was the tradition for all those who were involved in a case of Lian)}}
\hadithdefcmd{bukhari}{5309}{حَدَّثَنَا يَحْيَى، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، عَنِ الْمُلاَعَنَةِ، وَعَنِ السُّنَّةِ، فِيهَا عَنْ حَدِيثِ، سَهْلِ بْنِ سَعْدٍ أَخِي بَنِي سَاعِدَةَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ أَمْ كَيْفَ يَفْعَلُ فَأَنْزَلَ اللَّهُ فِي شَأْنِهِ مَا ذَكَرَ فِي الْقُرْآنِ مِنْ أَمْرِ الْمُتَلاَعِنَيْنِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ قَضَى اللَّهُ فِيكَ وَفِي امْرَأَتِكَ ‏"‏‏.‏ قَالَ فَتَلاَعَنَا فِي الْمَسْجِدِ وَأَنَا شَاهِدٌ، فَلَمَّا فَرَغَا قَالَ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا‏.‏ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ فَرَغَا مِنَ التَّلاَعُنِ، فَفَارَقَهَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ذَاكَ تَفْرِيقٌ بَيْنَ كُلِّ مُتَلاَعِنَيْنِ ‏"‏‏.‏ قَالَ ابْنُ جُرَيْجٍ قَالَ ابْنُ شِهَابٍ فَكَانَتِ السُّنَّةُ بَعْدَهُمَا أَنْ يُفَرَّقَ بَيْنَ الْمُتَلاَعِنَيْنِ، وَكَانَتْ حَامِلاً، وَكَانَ ابْنُهَا يُدْعَى لأُمِّهِ، قَالَ ثُمَّ جَرَتِ السُّنَّةُ فِي مِيرَاثِهَا أَنَّهَا تَرِثُهُ وَيَرِثُ مِنْهَا مَا فَرَضَ اللَّهُ لَهُ‏.‏ قَالَ ابْنُ جُرَيْجٍ عَنِ ابْنِ شِهَابٍ عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ فِي هَذَا الْحَدِيثِ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنْ جَاءَتْ بِهِ أَحْمَرَ قَصِيرًا كَأَنَّهُ وَحَرَةٌ، فَلاَ أُرَاهَا إِلاَّ قَدْ صَدَقَتْ وَكَذَبَ عَلَيْهَا، وَإِنْ جَاءَتْ بِهِ أَسْوَدَ أَعْيَنَ ذَا أَلْيَتَيْنِ، فَلاَ أُرَاهُ إِلاَّ قَدْ صَدَقَ عَلَيْهَا ‏"‏‏.‏ فَجَاءَتْ بِهِ عَلَى الْمَكْرُوهِ مِنْ ذَلِكَ‏.‏\hadithno{5309}\hadithtrans{Narrated Ibn Juraij:Ibn Shihab informed me of Lian and the tradition related to it, referring to the narration of Sahl bin Sa`d, the brother of Bani Sa`idi He said, "An Ansari man came to Allah's Messenger (ﷺ) and said, 'O Allah's Apostle! If a man saw another man with his wife, should he kill him, or what should he do?' So Allah revealed concerning his affair what is mentioned in the Holy Qur'an about the affair of those involved in a case of Lian. The Prophet (ﷺ) said, 'Allah has given His verdict regarding you and your wife.' So they carried out Lian in the mosque while I was present there. When they had finished, the man said, "O Allah's Messenger (ﷺ)! If I should now keep her with me as a wife then I have told a lie about her. Then he divorced her thrice before Allah's Messenger (ﷺ) ordered him, when they had finished the Lian process. So he divorced her in front of the Prophet (ﷺ) ." Ibn Shihab added, "After their case, it became a tradition that a couple involved in a case of Lian should be separated by divorce. That lady was pregnant then, and later on her son was called by his mother's name. The tradition concerning their inheritance was that she would be his heir and he would inherit of her property the share Allah had prescribed for him." Ibn Shihab said that Sahl bin Sa`d As'Saidi said that the Prophet (ﷺ) said (in the above narration), "If that lady delivers a small red child like a lizard, then the lady has spoken the truth and the man was a liar, but if she delivers a child with black eyes and huge lips, then her husband has spoken the truth." Then she delivered it in the shape one would dislike (as it proved her guilty)}}
\hadithdefcmd{bukhari}{5310}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ ذُكِرَ التَّلاَعُنُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً، ثُمَّ انْصَرَفَ، فَأَتَاهُ رَجُلٌ مِنْ قَوْمِهِ يَشْكُو إِلَيْهِ أَنَّهُ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، فَقَالَ عَاصِمٌ مَا ابْتُلِيتُ بِهَذَا إِلاَّ لِقَوْلِي، فَذَهَبَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا قَلِيلَ اللَّحْمِ سَبْطَ الشَّعَرِ، وَكَانَ الَّذِي ادَّعَى عَلَيْهِ أَنَّهُ وَجَدَهُ عِنْدَ أَهْلِهِ خَدْلاً آدَمَ كَثِيرَ اللَّحْمِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏‏.‏ فَجَاءَتْ شَبِيهًا بِالرَّجُلِ الَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَهُ، فَلاَعَنَ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمَا‏.‏ قَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ هِيَ الَّتِي قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ رَجَمْتُ هَذِهِ ‏"‏‏.‏ فَقَالَ لاَ تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ فِي الإِسْلاَمِ السُّوءَ قَالَ أَبُو صَالِحٍ وَعَبْدُ اللَّهِ بْنُ يُوسُفَ خَدِلاً‏.‏\hadithno{5310}\hadithtrans{Narrated Al-Qasim bin Muhammad:Ibn `Abbas; said, "Once Lian was mentioned before the Prophet (ﷺ) whereupon `Asim bin Adi said something and went away. Then a man from his tribe came to him, complaining that he had found a man with his wife. `Asim said, 'I have not been put to task except for my statement (about Lian).' `Asim took the man to the Prophet (ﷺ) and the man told him of the state in which he had found his wife. The man was pale, thin, and of lank hair, while the other man whom he claimed he had seen with his wife, was brown, fat and had much flesh on his calves. The Prophet (ﷺ) invoked, saying, 'O Allah! Reveal the truth.' So that lady delivered a child resembling the man whom her husband had mentioned he had found her with. The Prophet (ﷺ) then made them carry out Lian." Then a man from that gathering asked Ibn `Abbas, "Was she the same lady regarding which the Prophet (ﷺ) had said, 'If I were to stone to death someone without witness, I would have stoned this lady'?" Ibn `Abbas said, "No, that was another lady who, though being a Muslim, used to arouse suspicion by her outright misbehavior}}
\hadithdefcmd{bukhari}{5311}{حَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ قَذَفَ امْرَأَتَهُ فَقَالَ فَرَّقَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ، وَقَالَ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ فَأَبَيَا‏.‏ وَقَالَ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبُ ‏"‏‏.‏ فَأَبَيَا‏.‏ فَقَالَ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏ فَأَبَيَا فَفَرَّقَ بَيْنَهُمَا‏.‏ قَالَ أَيُّوبُ فَقَالَ لِي عَمْرُو بْنُ دِينَارٍ إِنَّ فِي الْحَدِيثِ شَيْئًا لاَ أَرَاكَ تُحَدِّثُهُ قَالَ قَالَ الرَّجُلُ مَالِي قَالَ قِيلَ لاَ مَالَ لَكَ، إِنْ كُنْتَ صَادِقًا فَقَدْ دَخَلْتَ بِهَا، وَإِنْ كُنْتَ كَاذِبًا فَهْوَ أَبْعَدُ مِنْكَ‏.‏\hadithno{5311}\hadithtrans{Narrated Sa`id bin Jubair:I asked Ibn `Umar, "(What is the verdict if) a man accuses his wife of illegal sexual intercourse?" Ibn `Umar said, "The Prophet (ﷺ) separated (by divorce) the couple of Bani Al-Ajlan, and said, (to them), 'Allah knows that one of you two is a liar; so will one of you repent?' But both of them refused. He again said, 'Allah knows that one of you two is a liar; so will one of you repent?' But both of them refused. So he separated them by divorce." (Aiyub, a sub-narrator said: `Amr bin Dinar said to me, "There is something else in this Hadith which you have not mentioned. It goes thus: The man said, 'What about my money (i.e. the Mahr that I have given to my wife)?' It was said, 'You have no right to restore any money, for if you have spoken the truth (as regards the accusation), you have also consummated your marriage with her; and if you have told a lie, you are less rightful to have your money back}}
\hadithdefcmd{bukhari}{5312}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ الْمُتَلاَعِنَيْنِ،، فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لِلْمُتَلاَعِنَيْنِ ‏"‏ حِسَابُكُمَا عَلَى اللَّهِ أَحَدُكُمَا كَاذِبٌ، لاَ سَبِيلَ لَكَ عَلَيْهَا ‏"‏‏.‏ قَالَ مَالِي قَالَ ‏"‏ لاَ مَالَ لَكَ، إِنْ كُنْتَ صَدَقْتَ عَلَيْهَا، فَهْوَ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا، وَإِنْ كُنْتَ كَذَبْتَ عَلَيْهَا، فَذَاكَ أَبْعَدُ لَكَ ‏"‏‏.‏ قَالَ سُفْيَانُ حَفِظْتُهُ مِنْ عَمْرٍو‏.‏ وَقَالَ أَيُّوبُ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ لاَعَنَ امْرَأَتَهُ فَقَالَ بِإِصْبَعَيْهِ ـ وَفَرَّقَ سُفْيَانُ بَيْنَ إِصْبَعَيْهِ السَّبَّابَةِ وَالْوُسْطَى ـ فَرَّقَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ، وَقَالَ ‏"‏ اللَّهُ يَعْلَمُ إِنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ ثَلاَثَ مَرَّاتٍ‏.‏ قَالَ سُفْيَانُ حَفِظْتُهُ مِنْ عَمْرٍو وَأَيُّوبَ كَمَا أَخْبَرْتُكَ‏.‏\hadithno{5312}\hadithtrans{Narrated Sa`id bin Jubair:I asked Ibn `Umar about those who were involved in a case of Lien. He said, "The Prophet (ﷺ) said to those who were involved in a case of Lien, 'Your accounts are with Allah. One of you two is a liar, and you (the husband) have no right over her (she is divorced)." The man said, 'What about my property (Mahr) ?' The Prophet (ﷺ) said, 'You have no right to get back your property. If you have told the truth about her then your property was for the consummation of your marriage with her; and if you told a lie about her, then you are less rightful to get your property back.' " Sufyan, a sub-narrator said: I learned the Hadith from `Amr. Narrated Aiyub: I heard Sa`id bin Jubair saying, "I asked Ibn `Umar, 'If a man (accuses his wife for an illegal sexual intercourse and) carries out the process of Lian (what will happen)?' Ibn `Umar set two of his fingers apart. (Sufyan set his index finger and middle finger apart.) Ibn `Umar said, 'The Prophet (ﷺ) separated the couple of Bani Al-Ajlan by divorce and said thrice, "Allah knows that one of you two is a liar; so will one of you repent (to Allah)?}}
\hadithdefcmd{bukhari}{5313}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَّقَ بَيْنَ رَجُلٍ وَامْرَأَةٍ قَذَفَهَا، وَأَحْلَفَهُمَا‏.‏\hadithno{5313}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) separated (divorced) the wife from her husband who accused her for an illegal sexual intercourse, and made them take the oath of Lian}}
\hadithdefcmd{bukhari}{5314}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ لاَعَنَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ رَجُلٍ وَامْرَأَةٍ مِنَ الأَنْصَارِ، وَفَرَّقَ بَيْنَهُمَا‏.‏\hadithno{5314}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) made an Ansari man and his wife carry out Lian, and then separated them by divorce}}
\hadithdefcmd{bukhari}{5315}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لاَعَنَ بَيْنَ رَجُلٍ وَامْرَأَتِهِ، فَانْتَفَى مِنْ وَلَدِهَا فَفَرَّقَ بَيْنَهُمَا، وَأَلْحَقَ الْوَلَدَ بِالْمَرْأَةِ‏.‏\hadithno{5315}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) made a man and his wife carry out Lian, and the husband repudiated her child. So the Prophet got them separated (by divorce) and decided that the child belonged to the mother only}}
\hadithdefcmd{bukhari}{5316}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ ذُكِرَ الْمُتَلاَعِنَانِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً، ثُمَّ انْصَرَفَ فَأَتَاهُ رَجُلٌ مِنْ قَوْمِهِ، فَذَكَرَ لَهُ أَنَّهُ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، فَقَالَ عَاصِمٌ مَا ابْتُلِيتُ بِهَذَا الأَمْرِ إِلاَّ لِقَوْلِي‏.‏ فَذَهَبَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ، وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا قَلِيلَ اللَّحْمِ سَبْطَ الشَّعَرِ، وَكَانَ الَّذِي وَجَدَ عِنْدَ أَهْلِهِ آدَمَ خَدْلاً كَثِيرَ اللَّحْمِ جَعْدًا قَطَطًا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏‏.‏ فَوَضَعَتْ شَبِيهًا بِالرَّجُلِ الَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَ عِنْدَهَا، فَلاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا، فَقَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ هِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ لَرَجَمْتُ هَذِهِ ‏"‏‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لاَ تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ السُّوءَ فِي الإِسْلاَمِ‏.‏\hadithno{5316}\hadithtrans{Narrated Ibn `Abbas:Those involved in a case of Lian were mentioned before Allah's Messenger (ﷺ) `Asim bin Adi said something about that and then left. Later on a man from his tribe came to him and told him that he had found another man with his wife. On that `Asim said, "I have not been put to task except for what I have said (about Lian)." `Asim took the man to Allah's Messenger (ﷺ) and he told him of the state in which he found his wife. The man was pale, thin and lank-haired, while the other man whom he had found with his wife was brown, fat with thick calves and curly hair. Allah's Messenger (ﷺ) said, "O Allah! Reveal the truth." Then the lady delivered a child resembling the man whom her husband had mentioned he had found with her. So Allah's Messenger (ﷺ) ordered them to carry out Lien. A man from that gathering said to Ibn `Abbas, "Was she the same lady regarding whom Allah's Messenger (ﷺ) said, 'If I were to stone to death someone without witnesses, I would have stoned this lady'?" Ibn `Abbas said, "No, that was another lady who, though being a Muslim, used to arouse suspicion because of her outright misbehavior}}
\hadithdefcmd{bukhari}{5317}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رِفَاعَةَ، الْقُرَظِيَّ تَزَوَّجَ امْرَأَةً، ثُمَّ طَلَّقَهَا فَتَزَوَّجَتْ آخَرَ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ لَهُ أَنَّهُ لاَ يَأْتِيهَا، وَإِنَّهُ لَيْسَ مَعَهُ إِلاَّ مِثْلُ هُدْبَةٍ فَقَالَ ‏ "‏ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ، وَيَذُوقَ عُسَيْلَتَكِ ‏"‏‏.‏\hadithno{5317}\hadithtrans{Narrated `Aisha:Rifa`a Al-Qurazi married a lady and then divorced her whereupon she married another man. She came to the Prophet (ﷺ) and said that her new husband did not approach her, and that he was completely impotent. The Prophet (ﷺ) said (to her), "No (you cannot remarry your first husband) till you taste the second husband and he tastes you (i.e. till he consummates his marriage with you)}}
\hadithdefcmd{bukhari}{5318}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ عَنْ أُمِّهَا أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ امْرَأَةً مِنْ أَسْلَمَ يُقَالُ لَهَا سُبَيْعَةُ كَانَتْ تَحْتَ زَوْجِهَا، تُوُفِّيَ عَنْهَا وَهْىَ حُبْلَى، فَخَطَبَهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ، فَأَبَتْ أَنْ تَنْكِحَهُ، فَقَالَ وَاللَّهِ مَا يَصْلُحُ أَنْ تَنْكِحِيهِ حَتَّى تَعْتَدِّي آخِرَ الأَجَلَيْنِ‏.‏ فَمَكُثَتْ قَرِيبًا مِنْ عَشْرِ لَيَالٍ ثُمَّ جَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ انْكِحِي ‏"‏‏.‏\hadithno{5318}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) A lady from Bani Aslam, called Subai'a, become a widow while she was pregnant. Abu As-Sanabil bin Ba'kak demanded her hand in marriage, but she refused to marry him and said, "By Allah, I cannot marry him unless I have completed one of the two prescribed periods." About ten days later (after having delivered her child), she went to the Prophet (ﷺ) and he said (to her), "You can marry now}}
\hadithdefcmd{bukhari}{5319}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، عَنِ اللَّيْثِ، عَنْ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، كَتَبَ إِلَيْهِ أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ عَنْ أَبِيهِ، أَنَّهُ كَتَبَ إِلَى ابْنِ الأَرْقَمِ أَنْ يَسْأَلَ، سُبَيْعَةَ الأَسْلَمِيَّةَ كَيْفَ أَفْتَاهَا النَّبِيُّ صلى الله عليه وسلم فَقَالَتْ أَفْتَانِي إِذَا وَضَعْتُ أَنْ أَنْكِحَ‏.‏\hadithno{5319}\hadithtrans{Narrated `Abdullah bin `Abdullah:that his father had written to Ibn Al-Arqam a letter asking him to ask Subai'a Al-Aslamiya how the Prophet had given her the verdict. She said, "The Prophet, gave me his verdict that after I gave birth, I could marry}}
\hadithdefcmd{bukhari}{5320}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ سُبَيْعَةَ الأَسْلَمِيَّةَ، نُفِسَتْ بَعْدَ وَفَاةِ زَوْجِهَا، بِلَيَالٍ فَجَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَاسْتَأْذَنَتْهُ أَنْ تَنْكِحَ، فَأَذِنَ لَهَا، فَنَكَحَتْ‏.‏\hadithno{5320}\hadithtrans{Narrated Al-Miswer bin Makhrama:Subai'a Al-Aslamiya gave birth to a child a few days after the death of her husband. She came to the Prophet and asked permission to remarry, and the Prophet (ﷺ) gave her permission, and she got married}}
\hadithdefcmd{bukhari}{5322}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ سَمِعَهُ يَذْكُرُ، أَنَّ يَحْيَى بْنَ سَعِيدِ بْنِ الْعَاصِ، طَلَّقَ بِنْتَ عَبْدِ الرَّحْمَنِ بْنِ الْحَكَمِ، فَانْتَقَلَهَا عَبْدُ الرَّحْمَنِ، فَأَرْسَلَتْ عَائِشَةُ أُمُّ الْمُؤْمِنِينَ إِلَى مَرْوَانَ وَهْوَ أَمِيرُ الْمَدِينَةِ اتَّقِ اللَّهَ وَارْدُدْهَا إِلَى بَيْتِهَا‏.‏ قَالَ مَرْوَانُ فِي حَدِيثِ سُلَيْمَانَ إِنَّ عَبْدَ الرَّحْمَنِ بْنَ الْحَكَمِ غَلَبَنِي‏.‏ وَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ أَوَمَا بَلَغَكِ شَأْنُ فَاطِمَةَ بِنْتِ قَيْسٍ قَالَتْ لاَ يَضُرُّكَ أَنْ لاَ تَذْكُرَ حَدِيثَ فَاطِمَةَ‏.‏ فَقَالَ مَرْوَانُ بْنُ الْحَكَمِ إِنْ كَانَ بِكِ شَرٌّ فَحَسْبُكِ مَا بَيْنَ هَذَيْنِ مِنَ الشَّرِّ‏.‏\hadithno{5322}\hadithtrans{(Narrated Qasim bin Muhammad and Sulaiman bin Yasar:that Yahya bin Sa`id bin Al-`As divorced the daughter of `Abdur-Rahman bin Al-Hakarn. `Abdur- Rahman took her to his house. On that `Aisha sent a message to Marwan bin Al-Hakam who was the ruler of Medina, saying, "Fear Allah, and urge your brother) to return her to her house." Marwan (in Sulaiman's version) said, "Abdur-Rahman bin Al-Hakam did not obey me (or had a convincing argument)." (In Al-Qasim's versions Marwan said, "Have you not heard of the case of Fatima bint Qais?" Aisha said, "The case of Fatima bint Qais is not in your favor.' Marwan bin Al-Hakam said to `Aisha, "The reason that made Fatima bint Qais go to her father's house is just applicable to the daughter of `Abdur-Rahman)}}
\hadithdefcmd{bukhari}{5324}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا لِفَاطِمَةَ أَلاَ تَتَّقِي اللَّهَ، يَعْنِي فِي قَوْلِهَا لاَ سُكْنَى وَلاَ نَفَقَةَ\hadithno{5324}\hadithtrans{Narrated Al-Qasim:Aisha said, "What is wrong with Fatima? Why doesn't she fear Allah?" by saying that a divorced lady is not entitled to be provided with residence and sustenance (by her husband)}}
\hadithdefcmd{bukhari}{5326}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، قَالَ عُرْوَةُ بْنُ الزُّبَيْرِ لِعَائِشَةَ أَلَمْ تَرَيْنَ إِلَى فُلاَنَةَ بِنْتِ الْحَكَمِ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ فَخَرَجَتْ‏.‏ فَقَالَتْ بِئْسَ مَا صَنَعَتْ‏.‏ قَالَ أَلَمْ تَسْمَعِي فِي قَوْلِ فَاطِمَةَ قَالَتْ أَمَا إِنَّهُ لَيْسَ لَهَا خَيْرٌ فِي ذِكْرِ هَذَا الْحَدِيثِ‏.‏ وَزَادَ ابْنُ أَبِي الزِّنَادِ عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَابَتْ عَائِشَةُ أَشَدَّ الْعَيْبِ وَقَالَتْ إِنَّ فَاطِمَةَ كَانَتْ فِي مَكَانٍ وَحِشٍ فَخِيفَ عَلَى نَاحِيَتِهَا، فَلِذَلِكَ أَرْخَصَ لَهَا النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{5326}\hadithtrans{Narrated Qasim:Urwa said to Aisha, "Do you know so-and-so, the daughter of Al-Hakam? Her husband divorced her irrevocably and she left (her husband's house)." `Aisha said, "What a bad thing she has done!" 'Urwa said (to `Aisha), "Haven't you heard the statement of Fatima?" `Aisha replied, "It is not in her favor to mention." 'Urwa added, `Aisha reproached (Fatima) severely and said, "Fatima was in a lonely place, and she was prone to danger, so the Prophet (ﷺ) allowed her (to go out of her husband's house)}}
\hadithdefcmd{bukhari}{5328}{وَحَدَّثَنِي حِبَّانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَنْكَرَتْ ذَلِكَ عَلَى فَاطِمَةَ‏.‏\hadithno{5328}\hadithtrans{Narrated 'Urwa:Aisha disapproved of what Fatima used to say}}
\hadithdefcmd{bukhari}{5329}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنْفِرَ إِذَا صَفِيَّةُ عَلَى باب خِبَائِهَا كَئِيبَةً، فَقَالَ لَهَا ‏"‏ عَقْرَى ـ أَوْ حَلْقَى ـ إِنَّكِ لَحَابِسَتُنَا أَكُنْتِ أَفَضْتِ يَوْمَ النَّحْرِ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ ‏"‏ فَانْفِرِي إِذًا ‏"‏‏.‏\hadithno{5329}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) decided to leave Mecca after the Hajj, he saw Safiyya, sad and standing at the entrance of her tent. He said to her, "Aqr (or) Halq! You will detain us. Did you perform Tawaf-al- Ifada on the day of Nahr? She said, "Yes." He said, "Then you can depart}}
\hadithdefcmd{bukhari}{5330}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، قَالَ زَوَّجَ مَعْقِلٌ أُخْتَهُ فَطَلَّقَهَا تَطْلِيقَةً‏.‏\hadithno{5330}\hadithtrans{Narrated Al-Hasan:Ma'qil gave his sister in marriage and later her husband divorced her once}}
\hadithdefcmd{bukhari}{5331}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، حَدَّثَنَا الْحَسَنُ، أَنَّ مَعْقِلَ بْنَ يَسَارٍ، كَانَتْ أُخْتُهُ تَحْتَ رَجُلٍ فَطَلَّقَهَا، ثُمَّ خَلَّى عَنْهَا حَتَّى انْقَضَتْ عِدَّتُهَا، ثُمَّ خَطَبَهَا فَحَمِيَ مَعْقِلٌ مِنَ ذَلِكَ أَنَفًا فَقَالَ خَلَّى عَنْهَا وَهْوَ يَقْدِرُ عَلَيْهَا، ثُمَّ يَخْطُبُهَا فَحَالَ بَيْنَهُ وَبَيْنَهَا، فَأَنْزَلَ اللَّهُ ‏\{‏وَإِذَا طَلَّقْتُمُ النِّسَاءَ فَبَلَغْنَ أَجَلَهُنَّ فَلاَ تَعْضُلُوهُنَّ‏\}‏ إِلَى آخِرِ الآيَةِ، فَدَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَأَ عَلَيْهِ، فَتَرَكَ الْحَمِيَّةَ وَاسْتَقَادَ لأَمْرِ اللَّهِ‏.‏\hadithno{5331}\hadithtrans{Narrated Al-Hasan:The sister of Ma'qil bin Yasar was married to a man and then that man divorced her and remained away from her till her period of the 'Iddah expired. Then he demanded for her hand in marriage, but Ma'qil got angry out of pride and haughtiness and said, "He kept away from her when he could still retain her, and now he demands her hand again?" So Ma'qil disagreed to remarry her to him. Then Allah revealed: 'When you have divorced women and they have fulfilled the term of their prescribed period, do not prevent them from marrying their (former) husbands.' (2.232) So the Prophet (ﷺ) sent for Ma'qil and recited to him (Allah's order) and consequently Ma'qil gave up his pride and haughtiness and yielded to Allah's order}}
\hadithdefcmd{bukhari}{5332}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنهما ـ طَلَّقَ امْرَأَةً لَهُ وَهْىَ حَائِضٌ تَطْلِيقَةً وَاحِدَةً، فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُرَاجِعَهَا، ثُمَّ يُمْسِكَهَا حَتَّى تَطْهُرَ، ثُمَّ تَحِيضَ عِنْدَهُ حَيْضَةً أُخْرَى، ثُمَّ يُمْهِلَهَا حَتَّى تَطْهُرَ مِنْ حَيْضِهَا، فَإِنْ أَرَادَ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا حِينَ تَطْهُرُ مِنْ قَبْلِ أَنْ يُجَامِعَهَا، فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ‏.‏ وَكَانَ عَبْدُ اللَّهِ إِذَا سُئِلَ عَنْ ذَلِكَ قَالَ لأَحَدِهِمْ إِنْ كُنْتَ طَلَّقْتَهَا ثَلاَثًا فَقَدْ حَرُمَتْ عَلَيْكَ، حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ‏.‏ وَزَادَ فِيهِ غَيْرُهُ عَنِ اللَّيْثِ حَدَّثَنِي نَافِعٌ قَالَ ابْنُ عُمَرَ لَوْ طَلَّقْتَ مَرَّةً أَوْ مَرَّتَيْنِ، فَإِنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَنِي بِهَذَا‏.‏\hadithno{5332}\hadithtrans{Narrated Nafi`:Ibn `Umar bin Al-Khattab divorced his wife during her menses. Allah's Messenger (ﷺ) ordered him to take her back till she became clean, and when she got another period while she was with him, she should wait till she became clean again and only then, if he wanted to divorce her, he could do so before having sexual relations with her. And that is the period Allah has fixed for divorcing women. Whenever `Abdullah (bin `Umar) was asked about that, he would say to the questioner, "If you divorced her thrice, she is no longer lawful for you unless she marries another man (and the other man divorces her in his turn).' Ibn `Umar further said, 'Would that you (people) only give one or two divorces, because the Prophet (ﷺ) has ordered me so}}
\hadithdefcmd{bukhari}{5333}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، حَدَّثَنِي يُونُسُ بْنُ جُبَيْرٍ، سَأَلْتُ ابْنَ عُمَرَ فَقَالَ طَلَّقَ ابْنُ عُمَرَ امْرَأَتَهُ وَهْىَ حَائِضٌ، فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُرَاجِعَهَا، ثُمَّ يُطَلِّقَ مِنْ قُبُلِ عِدَّتِهَا، قُلْتُ فَتَعْتَدُّ بِتِلْكَ التَّطْلِيقَةِ قَالَ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ‏.‏\hadithno{5333}\hadithtrans{Narrated Yunus Ibn Jubair:Ibn `Umar divorced his wife while she was having her menses. `Umar asked the Prophet (ﷺ) who said, "Order him (your son) to take her back, and then divorced her before her period of the 'Iddah has elapsed." I asked Ibn `Umar, "Will that divorce (during the menses) be counted?" He replied, "If somebody behaves foolishly (will his foolishness be an excuse for his misbehavior)?}}
\hadithdefcmd{bukhari}{5334}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ بْنُ حَرْبٍ، فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً، ثُمَّ مَسَّتْ بِعَارِضَيْهَا، ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ، غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{5334}\hadithtrans{Narrated Humaid bin Nafi`:Zainab bint Abu Salama told me these three narrations: Zainab said: I went to Um Habiba, the wife of the Prophet (ﷺ) when her father, Abu- Sufyan bin Herb had died. Um ,Habiba asked for a perfume which contained yellow scent (Khaluq) or some other scent, and she first perfumed one of the girls with it and then rubbed her cheeks with it and said, "By Allah, I am not in need of perfume, but I have heard Allah's Messenger (ﷺ) saying, 'It is not lawful for a lady who believes in Allah and the Last Day to mourn for a dead person for more than three days unless he is her husband for whom she should mourn for four months and ten days}}
\hadithdefcmd{bukhari}{5335}{قَالَتْ زَيْنَبُ فَدَخَلْتُ عَلَى زَيْنَبَ ابْنَةِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا، فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ، ثُمَّ قَالَتْ أَمَا وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{5335}\hadithtrans{Zainab further said:I want to Zainab bint Jahsh when her brother died. She asked for perfume and used some of it and said, "By Allah, I am not in need of perfume, but I have heard Allah's Messenger (ﷺ) saying on the pulpit, 'It is not lawful for a lady who believes in Allah and the last day to mourn for more than three days except for her husband for whom she should mourn for four months and ten days}}
\hadithdefcmd{bukhari}{5336}{قَالَتْ زَيْنَبُ وَسَمِعْتُ أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنَهَا أَفَتَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلَّ ذَلِكَ يَقُولُ لاَ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ، وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏‏.‏\hadithno{5336}\hadithtrans{Zainab further said:"I heard my mother, Um Salama saying that a woman came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! The husband of my daughter has died and she is suffering from an eye disease, can she apply kohl to her eye?" Allah's Messenger (ﷺ) replied, "No," twice or thrice. (Every time she repeated her question) he said, "No." Then Allah's Messenger (ﷺ) added, "It is just a matter of four months and ten days. In the Pre-Islamic Period of ignorance a widow among you should throw a globe of dung when one year has elapsed}}
\hadithdefcmd{bukhari}{5337}{قَالَ حُمَيْدٌ فَقُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا، وَلَبِسَتْ شَرَّ ثِيَابِهَا، وَلَمْ تَمَسَّ طِيبًا حَتَّى تَمُرَّ بِهَا سَنَةٌ، ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَائِرٍ فَتَفْتَضُّ بِهِ، فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ، ثُمَّ تَخْرُجُ فَتُعْطَى بَعَرَةً فَتَرْمِي، ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ‏.‏ سُئِلَ مَالِكٌ مَا تَفْتَضُّ بِهِ قَالَ تَمْسَحُ بِهِ جِلْدَهَا‏.‏\hadithno{5337}\hadithtrans{I (Humaid) said to Zainab, "What does 'throwing a globe of dung when one year had elapsed' mean?" Zainab said, "When a lady was bereaved of her husband, she would live in a wretched small room and put on the worst clothes she had and would not touch any scent till one year had elapsed. Then she would bring an animal, e.g. a donkey, a sheep or a bird and rub her body against it. The animal against which she would rub her body would scarcely survive. Only then she would come out of her room, whereupon she would be given a globe of dung which she would throw away and then she would use the scent she liked or the like}}
\hadithdefcmd{bukhari}{5338}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا حُمَيْدُ بْنُ نَافِعٍ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّهَا، أَنَّ امْرَأَةً، تُوُفِّيَ زَوْجُهَا فَخَشُوا عَلَى عَيْنَيْهَا فَأَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَأْذَنُوهُ فِي الْكُحْلِ فَقَالَ ‏ "‏ لاَ تَكَحَّلْ قَدْ كَانَتْ إِحْدَاكُنَّ تَمْكُثُ فِي شَرِّ أَحْلاَسِهَا أَوْ شَرِّ بَيْتِهَا، فَإِذَا كَانَ حَوْلٌ فَمَرَّ كَلْبٌ رَمَتْ بِبَعَرَةٍ، فَلاَ حَتَّى تَمْضِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ ‏"‏‏.‏\hadithno{5338}\hadithtrans{Narrated Um Salama: A woman was bereaved of her husband and her relatives worried about her eyes (which were diseased). They came to Allah's Messenger (ﷺ), and asked him to allow them to treat her eyes with kohl, but he said, "She should not apply kohl to her eyes. (In the Pre-Islamic period of Ignorance) a widowed woman among you would stay in the worst of her clothes (or the worst part of her house) and when a year had elapsed, if a dog passed by her, she would throw a globe of dung, Nay, (she cannot use kohl) till four months and ten days have elapsed}}
\hadithdefcmd{bukhari}{5339}{وَسَمِعْتُ زَيْنَبَ ابْنَةَ أُمِّ سَلَمَةَ، تُحَدِّثُ عَنْ أُمِّ حَبِيبَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ مُسْلِمَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ فَوْقَ ثَلاَثَةِ أَيَّامٍ، إِلاَّ عَلَى زَوْجِهَا أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{5339}\hadithtrans{Narrated Um Habiba:The Prophet (ﷺ) said, "It is not lawful for a Muslim woman who believes in Allah and the Last Day to mourn for more than three days, except for her husband, for whom she should mourn for four months and ten days}}
\hadithdefcmd{bukhari}{5340}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا سَلَمَةُ بْنُ عَلْقَمَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَتْ أُمُّ عَطِيَّةَ نُهِينَا أَنْ نُحِدَّ أَكْثَرَ مِنْ ثَلاَثٍ إِلاَّ بِزَوْجٍ‏.‏\hadithno{5340}\hadithtrans{Narrated Um 'Atiyya:We were forbidden to mourn for more than three days except for a husband}}
\hadithdefcmd{bukhari}{5341}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا نُنْهَى أَنْ نُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا، وَلاَ نَكْتَحِلَ، وَلاَ نَطَّيَّبَ، وَلاَ نَلْبَسَ ثَوْبًا مَصْبُوغًا، إِلاَّ ثَوْبَ عَصْبٍ، وَقَدْ رُخِّصَ لَنَا عِنْدَ الطُّهْرِ إِذَا اغْتَسَلَتْ إِحْدَانَا مِنْ مَحِيضِهَا فِي نُبْذَةٍ مِنْ كُسْتِ أَظْفَارٍ، وَكُنَّا نُنْهَى عَنِ اتِّبَاعِ الْجَنَائِزِ‏.‏\hadithno{5341}\hadithtrans{Narrated Um 'Atiyya:We were forbidden to mourn for more than three days for a dead person, except for a husband, for whom a wife should mourn for four months and ten days (while in the mourning period) we were not allowed to put kohl in our eyes, nor perfume our-selves, nor wear dyed clothes, except a garment of 'Asb (special clothes made in Yemen). But it was permissible for us that when one of us became clean from her menses and took a bath, she could use a piece of a certain kind of incense. And it was forbidden for us to follow funeral processions}}
\hadithdefcmd{bukhari}{5342}{حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ، فَإِنَّهَا لاَ تَكْتَحِلُ وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ ‏"‏‏.‏\hadithno{5342}\hadithtrans{Narrated Um 'Atiyya:The Prophet (ﷺ) said, "It is not lawful for a lady who believes in Allah and the Last Day, to mourn for more than three days for a dead person, except for her husband, in which case she should neither put kohl in her eyes, nor perfume herself, nor wear dyed clothes, except a garment of 'Asb}}
\hadithdefcmd{bukhari}{5343}{وَقَالَ الأَنْصَارِيُّ حَدَّثَنَا هِشَامٌ، حَدَّثَتْنَا حَفْصَةُ، حَدَّثَتْنِي أُمُّ عَطِيَّةَ، نَهَى النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَلاَ تَمَسَّ طِيبًا إِلاَّ أَدْنَى طُهْرِهَا إِذَا طَهُرَتْ، نُبْذَةً مِنْ قُسْطٍ وَأَظْفَارٍ ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ الْقُسْطُ وَالْكُسْتُ مِثْلُ الْكَافُورِ وَالْقَافُورِ\hadithno{5343}\hadithtrans{Um 'Atiyya added:The Prophet (ﷺ) said, "She should not use perfume except when she becomes clean from her menses whereupon she can use Qust, and Azfar (two kinds of incense)}}
\hadithdefcmd{bukhari}{5344}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شِبْلٌ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا‏\}‏ قَالَ كَانَتْ هَذِهِ الْعِدَّةُ تَعْتَدُّ عِنْدَ أَهْلِ زَوْجِهَا وَاجِبًا، فَأَنْزَلَ اللَّهُ ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا وَصِيَّةً لأَزْوَاجِهِمْ مَتَاعًا إِلَى الْحَوْلِ غَيْرَ إِخْرَاجٍ فَإِنْ خَرَجْنَ فَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ فِي أَنْفُسِهِنَّ مِنْ مَعْرُوفٍ‏\}‏ قَالَ جَعَلَ اللَّهُ لَهَا تَمَامَ السَّنَةِ سَبْعَةَ أَشْهُرٍ وَعِشْرِينَ لَيْلَةً وَصِيَّةً إِنْ شَاءَتْ سَكَنَتْ فِي وَصِيَّتِهَا، وَإِنْ شَاءَتْ خَرَجَتْ، وَهْوَ قَوْلُ اللَّهِ تَعَالَى ‏\{‏غَيْرَ إِخْرَاجٍ فَإِنْ خَرَجْنَ فَلاَ جُنَاحَ عَلَيْكُمْ‏\}‏ فَالْعِدَّةُ كَمَا هِيَ، وَاجِبٌ عَلَيْهَا، زَعَمَ ذَلِكَ عَنْ مُجَاهِدٍ‏.‏ وَقَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ نَسَخَتْ هَذِهِ الآيَةُ عِدَّتَهَا عِنْدَ أَهْلِهَا، فَتَعْتَدُّ حَيْثُ شَاءَتْ، وَقَوْلُ اللَّهِ تَعَالَى ‏\{‏غَيْرَ إِخْرَاجٍ‏\}‏‏.‏ وَقَالَ عَطَاءٌ إِنْ شَاءَتِ اعْتَدَّتْ عِنْدَ أَهْلِهَا، وَسَكَنَتْ فِي وَصِيَّتِهَا، وَإِنْ شَاءَتْ خَرَجَتْ لِقَوْلِ اللَّهِ ‏\{‏فَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ‏\}‏‏.‏ قَالَ عَطَاءٌ ثُمَّ جَاءَ الْمِيرَاثُ فَنَسَخَ السُّكْنَى، فَتَعْتَدُّ حَيْثُ شَاءَتْ، وَلاَ سُكْنَى لَهَا‏.‏\hadithno{5344}\hadithtrans{Narrated Mujahid:(regarding the Verse): 'If any of you dies and leaves wives behind,' That was the period of the 'Iddah which the widow was obliged to spend in the house of the late husband. Then Allah revealed: And those of you who die and leave wives should bequeath for their wives a year's maintenance and residence without turning them out, but if they leave, there is no blame on you for what they do of themselves, provided it is honorable (i.e. lawful marriage) (2.240) Mujahid said: Allah has ordered that a widow has the right to stay for seven months and twenty days with her husband's relatives through her husband's will and testament so that she will complete the period of one year (of 'Iddah). But the widow has the right to stay that extra period or go out of her husband's house as is indicated by the statement of Allah: 'But if they leave there is no blame on you,... ' (2.240) Ibn `Abbas said: The above Verse has cancelled the order of spending the period of the 'Iddah at her late husband's house, and so she could spend her period of the 'Iddah wherever she likes. And Allah says: 'Without turning them out.' 'Ata said: If she would, she could spend her period of the 'Iddah at her husband's house, and live there according to her (husband's) will and testament, and if she would, she could go out (of her husband's house) as Allah says: 'There is no blame on you for what they do of themselves.' (2.240) 'Ata added: Then the Verses of inheritance were revealed and the order of residence (for the widow) was cancelled, and she could spend her period of the 'Iddah wherever she would like, and she was no longer entitled to be accommodated by her husband's family}}
\hadithdefcmd{bukhari}{5345}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، حَدَّثَنِي حُمَيْدُ بْنُ نَافِعٍ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّ حَبِيبَةَ ابْنَةِ أَبِي سُفْيَانَ، لَمَّا جَاءَهَا نَعِيُّ أَبِيهَا دَعَتْ بِطِيبٍ، فَمَسَحَتْ ذِرَاعَيْهَا وَقَالَتْ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ‏.‏ لَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{5345}\hadithtrans{Narrated Zainab bint Um Salama:When Um Habiba bint Abi Sufyan was informed of her father's death, she asked for perfume and rubbed it over her arms and said, "I am not in need of perfume, but I have heard the Prophet (ﷺ) saying, "It is not lawful for a lady who believes in Allah and the Last Day to mourn for more than three days except for her husband for whom the (mourning) period is four months and ten days}}
\hadithdefcmd{bukhari}{5346}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ، وَحُلْوَانِ الْكَاهِنِ، وَمَهْرِ الْبَغِيِّ‏.‏\hadithno{5346}\hadithtrans{Narrated Abu Mas`ud:The Prophet (ﷺ) prohibited taking the price of a dog, the earnings of a soothsayer and the money earned by prostitution}}
\hadithdefcmd{bukhari}{5347}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَوْنُ بْنُ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْوَاشِمَةَ، وَالْمُسْتَوْشِمَةَ، وَآكِلَ الرِّبَا وَمُوكِلَهُ، وَنَهَى عَنْ ثَمَنِ الْكَلْبِ، وَكَسْبِ الْبَغِيِّ، وَلَعَنَ الْمُصَوِّرِينَ‏.‏\hadithno{5347}\hadithtrans{Narrated Abu Juhaifa:The Prophet (ﷺ) cursed the lady who practices tattooing and the one who gets herself tattooed, and one who eats (takes) Riba' (usury) and the one who gives it. And he prohibited taking the price of a dog, and the money earned by prostitution, and cursed the makers of pictures}}
\hadithdefcmd{bukhari}{5348}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كَسْبِ الإِمَاءِ‏.‏\hadithno{5348}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade taking the earnings of a slave girl by prostitution}}
\hadithdefcmd{bukhari}{5349}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ قَذَفَ امْرَأَتَهُ فَقَالَ فَرَّقَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ وَقَالَ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ فَأَبَيَا، فَقَالَ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ، فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ فَأَبَيَا، فَفَرَّقَ بَيْنَهُمَا‏.‏ قَالَ أَيُّوبُ فَقَالَ لِي عَمْرُو بْنُ دِينَارٍ فِي الْحَدِيثِ شَىْءٌ لاَ أَرَاكَ تُحَدِّثُهُ قَالَ قَالَ الرَّجُلُ مَالِي‏.‏ قَالَ ‏"‏ لاَ مَالَ لَكَ، إِنْ كُنْتَ صَادِقًا فَقَدْ دَخَلْتَ بِهَا، وَإِنْ كُنْتَ كَاذِبًا فَهْوَ أَبْعَدُ مِنْكَ ‏"‏‏.‏\hadithno{5349}\hadithtrans{Narrated Sa`id bin Jubair:I said to Ibn `Umar, "If a man accuses his wife of illegal sexual intercourse (what is the judgment)?" He said, "Allah's Prophet separated the couple of Bani 'Ajlan (when the husband accused his wife for an illegal sexual intercourse). The Prophet (ﷺ) said, 'Allah knows that one of you two IS a liar; so will one of you repent?' But they refused. He then again said, 'Allah knows that one of you two is a liar; so will one of you repent?' But they refused, whereupon he separated them by divorce." Aiyub (a subnarrator) said: `Amr bin Dinar said to me, "In the narration there is something which I do not see you mentioning, i.e. the husband said, "What about my money (Mahr)?' The Prophet (ﷺ) said, "You are not entitled to take back money, for if you told the truth you have already entered upon her (and consummated your marriage with her) and if you are a liar then you are less entitled to take it back}}
\hadithdefcmd{bukhari}{5350}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِلْمُتَلاَعِنَيْنِ ‏"‏ حِسَابُكُمَا عَلَى اللَّهِ، أَحَدُكُمَا كَاذِبٌ، لاَ سَبِيلَ لَكَ عَلَيْهَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَالِي‏.‏ قَالَ ‏"‏ لاَ مَالَ لَكَ، إِنْ كُنْتَ صَدَقْتَ عَلَيْهَا، فَهْوَ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا، وَإِنْ كُنْتَ كَذَبْتَ عَلَيْهَا، فَذَاكَ أَبْعَدُ وَأَبْعَدُ لَكَ مِنْهَا ‏"‏‏.‏\hadithno{5350}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said to those who were involved in a case of Lian, "Your accounts are with Allah. One of you two is a liar. You (husband) have right on her (wife)." The husband said, "My money, O Allah's Apostle!" The Prophet (ﷺ) said, "You are not entitled to take back any money. If you have told the truth, the Mahr that you paid, was for having sexual relations with her lawfully; and if you are a liar, then you are less entitled to get it back}}
